/*  FWER notes:
    Bonferroni is too conservative because:
        (a) No adjustment for double-counting the overlapping sets
        (b) No adjustment for dependence
        (c) No adjustment for evaluating all p-vals against the min p-val, even if the min p-val is rejected
    Sidak: Solves (a), not (b) or (c)
    Holm: Solves (a) and (c) (by removing hypotheses from the family once they are rejected), but not (b)
    Free step down resampling: Solves (a), (b), and (c)
*/
clear
clear matrix
set more off
set maxvar 5000

local nrand = 1000

foreach loop_nb of numlist 1/4 { // SMS: I added this loop, so we could run over the 4 different versions (Lasso and no Lasso, 2016 and 2017)

// SMS: I had to add these locals for the versions with and without Lasso, and the 2016/2017 versions
if inlist(`loop_nb', 1, 3) local lasso = 0
if inlist(`loop_nb', 2, 4) local lasso = 1

if inlist(`loop_nb', 1, 2) local yr = 2016
if inlist(`loop_nb', 3, 4) local yr = 2017

if `yr' == 2016 & `lasso' == 1 { // SMS: I manually copied in all these controls
local flattv_controls mar10_personalsquattoilet jul10_computer jul10_lease jul10_personaltoilet jul10_watt2200 pool11_concreteroof pool11_soilfloor pool11_wattnometer pool11_electricity pool12_computer pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool12_electricity pool12_personalsquattoile pool12_mutualsquattoilet pool13_ownhouse pool13_watt2200 pool13_kerosene pool13_personalgoosetoile pool14_computer pool14_concreteroof pool14_bottledcookwater pool14_electricity mar15_cleandrinkwater mar15_publicinternet mar15_int_financial mar15_marblegranitefloor mar15_soilfloor mar15_personaltoilet mar15_notbuyingdrinkwater mar15_mutualsquattoilet feb07_concreteroof jul07_concreteroof jul08_landlineforinternet jul08_concreteroof jul09_homeforinternet jul09_n_hhotherinternet jul09_concreteroof jul09_personaltoilet jul09_watt2200higher jul09_personalsquattoilet urban
local wcgoose_controls jul10_bamboofloor jul10_squattoilet pool12_riverdrinkwater pool12_goosetoilet pool13_riverdrinkwater pool13_personalgoosetoile pool14_unprotspringdrinkw pool14_personalgoosetoile mar15_personaltoilet mar15_notbuyingdrinkwater mar15_nonelectricity mar15_personalsquattoilet mar15_publicsquattoilet feb07_otherelectricity mar08_otherroof mar08_personaltoilet mar09_riverdrinkwater mar09_otherelectricity
local n_cell_controls jul10_computer jul10_bamboofloor pool11_concreteroof pool11_soilfloor pool12_computer pool12_concreteroof pool13_hhhouse4 pool14_computer pool14_bottledcookwater pool14_refillcookwater mar15_cleandrinkwater mar15_schoolinternet mar15_publicinternet mar15_personaltoilet feb07_publicwater jul07_officeforinternet mar08_publicwater jul08_landlineforinternet mar09_rent jul09_watt2200higher urban
local total_room_controls pool11_shingleroof pool12_residential pool13_woodfloor pool13_publicsquattoilet mar15_personaltoilet mar15_riverdrinkwater mar15_publicnotoilet
}
if `yr' == 2017 & `lasso' == 1 {
local flattv_controls mar10_concreteroof jul10_laptop jul10_lease jul10_watt2200 jul10_mutualsquattoilet pool11_lease pool11_personalgoosetoile pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool13_rent pool14_computer pool14_bottledcookwater pool14_refillcookwater mar15_cleandrinkwater mar15_officeinternet mar15_int_financial mar15_lease mar15_concreteroof mar15_marblegranitefloor mar15_refillwashwater jul07_lease jul07_concreteroof mar08_lease jul08_landlineforinternet jul08_asbestosroof jul09_homeforinternet jul09_personaltoilet jul09_watt2200 jul09_watt2200higher urban
local wcgoose_controls pool11_personalgoosetoile pool11_personalsquattoile pool12_personalsquattoile pool13_oillamp pool14_mutualsquattoilet mar15_personaltoilet mar15_noaccesswater mar15_personalunclosedpit feb07_notoilet jul07_publicnotoilet mar08_goosetoilet
local n_cell_controls jul10_lease pool11_soilfloor pool11_publicwater pool12_computer pool12_concreteroof pool14_computer pool14_bottledcookwater mar15_cleandrinkwater mar15_officeinternet mar15_publicinternet mar15_int_financial mar15_personaltoilet jul07_officeforinternet jul07_lease jul08_landlineforinternet mar09_rent urban
local total_room_controls jul10_parrafinlamp pool12_residential pool13_residential pool13_woodfloor pool13_riverdrinkwater mar15_personaltoilet mar15_riverdrinkwater jul07_publicnotoilet
}
if `lasso' == 0 {
local flattv_controls ""
local wcgoose_controls ""
local n_cell_controls ""
local total_room_controls ""   
}

// SMS: I added this in to select the correct data set
if `yr' == 2016 use "$codeddata/180529_final_database_imputem_2016susenas.dta", clear
if `yr' == 2017 use "$codeddata/180529_final_database_imputem_2017susenas.dta", clear

// Generate variables to store actual and simulated t-stats/p-vals 
local counter = 1
gen str20 varname = ""
gen float tstat = .
gen float act_pval = .
gen float tstatsim = .
gen float pvalsim = .
gen float pvals = .

order varname tstat act_pval tstatsim pvalsim pvals

// Run the original regressions for all of the different outcomes tested and store the actual (observed) p-vals/t-stats

// SMS: I adjusted the code that ran the actual regressions

*1. tv
areg own_flattv tr_tv tr_cell `flattv_controls', absorb(strata_orig) cluster(province)
quietly replace tstat = abs( _b[tr_tv] / _se[tr_tv] ) in 1
quietly replace act_pval = 2 * ttail( e(N), abs( tstat ) ) in 1
quietly replace varname = "own_flattv" in 1
local own_flattv_ct_0 = 0

*2. cell
areg n_cell_hh tr_tv tr_cell `n_cell_controls', absorb(strata_orig) cluster(province)
quietly replace tstat = abs( _b[tr_cell] / _se[tr_cell] ) in 2
quietly replace act_pval = 2 * ttail( e(N), abs( tstat ) ) in 2
quietly replace varname = "n_cell_hh" in 2
local n_cell_hh_ct_0 = 0

*3. rooms
areg total_room tr_room tr_wc `total_room_controls', absorb(strata_orig) cluster(province)
quietly replace tstat = abs( _b[tr_room] / _se[tr_room] ) in 3
quietly replace act_pval = 2 * ttail( e(N), abs( tstat ) ) in 3
quietly replace varname = "total_room" in 3
local total_room_ct_0 = 0

*4. wc
areg own_wcgoose tr_room tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
quietly replace tstat = abs( _b[tr_wc] / _se[tr_wc] ) in 4
quietly replace act_pval = 2 * ttail( e(N), abs( tstat ) ) in 4
quietly replace varname = "own_wcgoose" in 4
local own_wcgoose_ct_0 = 0

// Sort the p-vals by the actual (observed) p-vals (this will reorder some of the obs in your data set, but that shouldn't matter).

gsort act_pval

local endvar = 4 // there are 4 outcome variables in total

// Generate the variable that will contain the simulated (placebo) treatments

*merge with random treatments // SMS: I had to add this in here. I followed our randomization procedure to create these placebo treatments.
rename province province_string
rename code province
merge m:1 province using "$fake_tx/fake_tx.dta", force
assert _merge == 3
drop _merge

local i = 1

gsort act_pval
preserve
    keep if _n <= 4
    list varname
    assert !missing(varname)
restore

// Run 10,000 iterations of the simulation; record results in p-val storage counters
while `i' <= `nrand' {

    gen tr_cell_`i' = 1 - tr_wc_`i'
    gen tr_room_`i' = 1 - tr_tv_`i'

    di as error "On loop `i' out of `nrand'..."
// In this section we assign the placebo treatments and run regressions using the placebo treatments

	// SMS: again, I had to adjust the regression specifications and the treatment variable from which the relevant p-value came from.
    *1. tv
    areg own_flattv tr_tv_`i' tr_cell_`i' `flattv_controls', absorb(strata_orig) cluster(province)
    quietly replace tstatsim = abs( _b[tr_tv_`i'] / _se[tr_tv_`i'] ) in 1
    quietly replace pvalsim = 2 * ttail( e(N), abs( tstatsim ) ) in 1

    *2. cell
    areg n_cell_hh tr_tv_`i' tr_cell_`i' `n_cell_controls', absorb(strata_orig) cluster(province)
    quietly replace tstatsim = abs( _b[tr_cell_`i'] / _se[tr_cell_`i'] ) in 2
    quietly replace pvalsim = 2 * ttail( e(N), abs( tstatsim ) ) in 2

    *3. rooms
    areg total_room tr_room_`i' tr_wc_`i' `total_room_controls', absorb(strata_orig) cluster(province)
    quietly replace tstatsim = abs( _b[tr_room_`i'] / _se[tr_room_`i'] ) in 3
    quietly replace pvalsim = 2 * ttail( e(N), abs( tstatsim ) ) in 3

    *4. wc
    areg own_wcgoose tr_room_`i' tr_wc_`i' `wcgoose_controls', absorb(strata_orig) cluster(province)
    quietly replace tstatsim = abs( _b[tr_wc_`i'] / _se[tr_wc_`i'] ) in 4
    quietly replace pvalsim = 2 * ttail( e(N), abs( tstatsim ) ) in 4

	// SMS: I did not need to adjust the following, the Step-Down procedure, the main part of this entire process.
// In this section we perform the "step down" procedure that replaces simulated p-vals with the minimum of the set of simulated p-vals associated with outcomes that had actual p-vals greater than or equal to the one being replaced.  For each outcome, we keep count of how many times the ultimate simulated p-val is less than the actual observed p-val.
    local countdown = `endvar'
    while `countdown' >= 1 {
        di as error "on variable `countdown' out of `endvar'"
        quietly replace pvalsim = min( pvalsim, pvalsim[_n+1] ) in `countdown'
        local depvar = varname[`countdown']
        if pvalsim[`countdown'] <= act_pval[`countdown'] {
            local `depvar'_ct_0 = ``depvar'_ct_0' + 1
        }
        local countdown = `countdown' - 1
	}

    drop *_`i'

    local i = `i' + 1
}

// SMS: I added the following code to debug, to make sure everything was working correctly.
gen pvals_orig = pvals
gsort act_pval
preserve
    keep if _n <= 4
    list varname
    assert !missing(varname)
restore

// Perform the final adjustment that ensures that the ordering to adjusted p-vals is the same as the original ordering of actual p-vals.
// Note: this code enforces monotonicity below by going from the smallest (most significant) to the largest (least significant) p-value, but the original 2008 JASA paper describes the algorithm on p. 1486 as going from the largest p-value to the smallest p-value. The code is correct; the paper has a typo.

foreach lhsvar of numlist 1/`endvar' {
    local depvar = varname[`lhsvar']
    di "finalizing p-value for variable `depvar' in row `lhsvar'"
    replace pvals = max( round( ``depvar'_ct_0' / `nrand', 0.001 ), pvals[`lhsvar'-1] ) in `lhsvar'
}


// SMS: I added this code so we could export the results
keep if !missing(varname)
keep act_pval pvals varname
export delimited using "$outpath/FWER_results_lasso_`lasso'_yr_`yr'.csv", replace

}
*DONE!!!

