%% preliminary

% LASSO regressions for SUSENAS survey experiment.

% change file directory here
cd ''


%We will be writing selected controls to the following do-file template
TemplateFile = fopen('matlabregressions.do.temp','r'); % actual do file
Template = fscanf(TemplateFile,'%c'); % read data from text file
fclose(TemplateFile); % close do file

disp('DONE with preliminary section')

%% main loop

% iterate over following three cases:
% r = 1: not weighted, group mean
% r = 2: hand-weighted, group mean
% r = 3: not weighted, individual-level

for r = 3:3 % in final PPLS paper, we only consider case r = 3
    disp('starting loop number...')
    disp(r)
    % The varialbe DATA_SUFFIX determines which data are used for estimation:
    %    - 'inds' for individual level regressions
    %    - 'means' for group means
    if r <= 2
        DATA_SUFFIX = 'means';
    else
        DATA_SUFFIX = 'inds';
    end

    % The variable WEIGHT_VARS determines whether we hand-weight the design matrix before 
    %   doing lasso selection.   
    if r == 2 %  group mean and hand-weighted
        WEIGHT_VARS = 1;
    else 
        WEIGHT_VARS = 0;
    end

    % Read Covariate Names
    ControlsFile = fopen(strcat('Data_2017/X_',DATA_SUFFIX,'_imputem_susenas_nocoll.csv'));
    Header = textscan(ControlsFile, '%s', 1);
    HeaderString = Header{1,1}{1,1};
    Vars = textscan(HeaderString,'%s','Delimiter',',');
    Vars = Vars{1,1};

    % clear no-longer needed variables
    clear ControlsFile Header HeaderString;

    % Load (Standardized) Data
    Controls = csvread(strcat('Data_2017/X_',DATA_SUFFIX,'_imputem_susenas_nocoll.csv'),1,0);
    [N, p] = size(Controls)

    TreatTV = csvread(strcat('Data_2017/tr_tv_',DATA_SUFFIX,'.csv'),1,0);
    TreatCell = csvread(strcat('Data_2017/tr_cell_',DATA_SUFFIX,'.csv'),1,0);
    TreatRoom = csvread(strcat('Data_2017/tr_room_',DATA_SUFFIX,'.csv'),1,0);
    TreatWC = csvread(strcat('Data_2017/tr_wc_',DATA_SUFFIX,'.csv'),1,0);

    OutTV = csvread(strcat('Data_2017/own_flattv_',DATA_SUFFIX,'.csv'),1,0);
    OutCell = csvread(strcat('Data_2017/n_cell_hh_',DATA_SUFFIX,'.csv'),1,0);
    OutRoom = csvread(strcat('Data_2017/total_room_hh_',DATA_SUFFIX,'.csv'),1,0);
    OutWC = csvread(strcat('Data_2017/own_wcgoose_',DATA_SUFFIX,'.csv'),1,0);

    Provinces = csvread(strcat('Data_2017/province_numeric_',DATA_SUFFIX,'.csv'),1,0);
    Strata = csvread(strcat('Data_2017/strata_numeric_',DATA_SUFFIX,'.csv'),1,0);
    
    % create dummyvar matrix
    S = dummyvar(Strata);
    
    % count number of unique values
    [nStrata,~] = size(unique(Strata));

    % Weight variables (when r = 2)
    if strcmp(DATA_SUFFIX,'means') && logical(WEIGHT_VARS)
        GroupSize = csvread('Data_2017/group_size_means.csv',1,0);
        Controls = Controls .* repmat(sqrt(GroupSize'),p,1)';
        TreatTV = TreatTV .* GroupSize;
        TreatCell = TreatCell .* GroupSize;
        TreatRoom = TreatRoom .* GroupSize;
        TreatWC = TreatWC .* GroupSize;
        OutTV = OutTV .* GroupSize;
        OutCell = OutCell .* GroupSize;
        OutRoom = OutRoom .* GroupSize;
        OutWC = OutWC .* GroupSize;

        %   We also want to weight the matrix we use to partial out strata
        %   fixed-effects
        S = S.* repmat(sqrt(GroupSize'),nStrata,1)';
    end
   
        % Partial out fixed-effects by strata
        ControlsWithin = Controls - S * (S\Controls);
        TreatTVWithin = TreatTV - S * (S\TreatTV);
        TreatCellWithin = TreatCell - S * (S\TreatCell);
        TreatRoomWithin = TreatRoom - S * (S\TreatRoom);
        TreatWCWithin = TreatWC - S * (S\TreatWC);
        OutTVWithin = OutTV - S * (S\OutTV);
        OutCellWithin = OutCell - S * (S\OutCell);
        OutRoomWithin = OutRoom - S * (S\OutRoom);
        OutWCWithin = OutWC - S * (S\OutWC);
        clear Controls TreatTV TreatWC TreatRoom TreatCell OutTV OutCell OutRoom OutWC;

        % Standardize potential controls
        ControlsWithin = normalize(ControlsWithin,1);
              
        % Compute penalty term for clustered lasso
        [nClusters, ~] = size(unique(Provinces));
        gamma = .1/log(nClusters);
        lambda = 2.2*sqrt(nClusters)*norminv(1-gamma/(2*p));

        %%%%%%%%%%%%%%%%%%%%%%%%%%%
        %%% DO LASSO ESTIMATION %%%
        %%%%%%%%%%%%%%%%%%%%%%%%%%%

        disp('starting LASSO ESTIMATION for loop number...')
        disp(r)

        disp('LASSO ESTIMATION for treatTV')
        bTreatTV = feasiblePostLasso(TreatTVWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selTreatTV = find(abs(bTreatTV) > 0);
        ControlsTreatTV = Vars(selTreatTV)

        disp('LASSO ESTIMATION for treatCell')
        bTreatCell = feasiblePostLasso(TreatCellWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selTreatCell = find(abs(bTreatCell) > 0);
        ControlsTreatCell = Vars(selTreatCell)

        disp('LASSO ESTIMATION for treatRoom')
        bTreatRoom = feasiblePostLasso(TreatRoomWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selTreatRoom = find(abs(bTreatRoom) > 0);
        ControlsTreatRoom = Vars(selTreatRoom)

        disp('LASSO ESTIMATION for treatWC')
        bTreatWC = feasiblePostLasso(TreatWCWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selTreatWC = find(abs(bTreatWC) > 0);
        ControlsTreatWC = Vars(selTreatWC)

        disp('LASSO ESTIMATION for outTV')
        bOutTV = feasiblePostLasso(OutTVWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selOutTV = find(abs(bOutTV) > 0);
        ControlsOutTV = Vars(selOutTV)

        disp('LASSO ESTIMATION for outCell')
        bOutCell = feasiblePostLasso(OutCellWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selOutCell = find(abs(bOutCell) > 0);
        ControlsOutCell = Vars(selOutCell)

        disp('LASSO ESTIMATION for outRoom')
        bOutRoom = feasiblePostLasso(OutRoomWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selOutRoom = find(abs(bOutRoom) > 0);
        ControlsOutRoom = Vars(selOutRoom)

        disp('LASSO ESTIMATION for outWC')
        bOutWC = feasiblePostLasso(OutWCWithin, ControlsWithin,'lambda',lambda,'initScale',0.5,'clusterVar',Provinces);
        selOutWC = find(abs(bOutWC) > 0);
        ControlsOutWC = Vars(selOutWC)
        
        disp('LASSO ESTIMATION for controls (TV, WC, Cell, Room)')
        ControlsTV = Vars(logical(abs(bTreatTV) + abs(bTreatCell) + abs(bOutTV)));
        ControlsCell = Vars(logical( abs(bTreatTV) + abs(bTreatCell) + abs(bOutCell)));
        ControlsRoom = Vars(logical( abs(bTreatRoom) + abs(bTreatWC) + abs(bOutRoom)));
        ControlsWC = Vars(logical( abs(bTreatRoom) + abs(bTreatWC) + abs(bOutWC)));
        
        % Write selected controls to template file.
    disp('now writing selected controls to template fill')
    if r == 1
        Template = strrep(Template,'$NOWEIGHTS_TV_CONTROLS',strjoin(ControlsTV));
        Template = strrep(Template,'$NOWEIGHTS_WC_CONTROLS',strjoin(ControlsWC));
        Template = strrep(Template,'$NOWEIGHTS_CELL_CONTROLS',strjoin(ControlsCell));
        Template = strrep(Template,'$NOWEIGHTS_ROOM_CONTROLS',strjoin(ControlsRoom));
    elseif r == 2
        Template = strrep(Template,'$WEIGHTS_TV_CONTROLS',strjoin(ControlsTV));
        Template = strrep(Template,'$WEIGHTS_WC_CONTROLS',strjoin(ControlsWC));
        Template = strrep(Template,'$WEIGHTS_CELL_CONTROLS',strjoin(ControlsCell));
        Template = strrep(Template,'$WEIGHTS_ROOM_CONTROLS',strjoin(ControlsRoom));
    elseif r == 3
        Template = strrep(Template,'$INDS_TV_CONTROLS',strjoin(ControlsTV));
        Template = strrep(Template,'$INDS_WC_CONTROLS',strjoin(ControlsWC));
        Template = strrep(Template,'$INDS_CELL_CONTROLS',strjoin(ControlsCell));
        Template = strrep(Template,'$INDS_ROOM_CONTROLS',strjoin(ControlsRoom));
    end
    
    clearvars -except Template;

end

disp('DONE with main loop')

%% save final do file

DoFile = fopen('matlabregressions_2017.do','w');
fprintf(DoFile, Template);
fclose(DoFile);

disp('DONE with final save')
disp('DONE WITH ENTIRE SCRIPT')
