*************************************************************
* Post-Lasso Regression for SUSENAS survey experiment
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off 

**********************************************************************
** lasso selected variables without weights (r=1 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls jul10_n_hhcellphone jul10_ownhouse jul10_shingleroof jul10_telephone mar15_bottledcookwater mar15_ceramicfloor mar15_clayroof mar15_marblegranitefloor mar15_n_officeinternet_hh mar15_noaccesstotoilet mar15_officeinternet mar15_useinternet pool11_cellphone pool11_month_exp pool11_telephone jul07_month_pcexp jul07_shingleroof jul08_mutualsquattoilet jul08_riverdrinkwater jul09_firewood mar08_riverdrinkwater

local wcgoose_controls jul10_motorcycle jul10_personalgoosetoilet jul10_shingleroof mar10_personalgoosetoilet mar15_firewood mar15_personalgoosetoilet mar15_personaltoilet mar15_riverdisposal pool11_marbleceramicfloor pool11_personalgoosetoile feb07_personalgoosetoilet jul07_personalgoosetoilet jul07_shingleroof jul09_fiberpalmroof jul09_oillamp
 
local n_cell_controls jul10_computer jul10_riverdisposal jul10_shingleroof jul10_watt1300 mar10_refrigerator mar15_n_homeinternet_hh pool11_cleanwatersanitati pool11_marbleceramicfloor pool11_telephone jul07_cellphone jul07_firewood jul07_shingleroof jul09_month_exp jul09_personalgoosetoilet mar09_personalgoosetoilet mar09_publicwater
 
local total_room_controls jul10_area jul10_personalgoosetoilet jul10_riverdrinkwater jul10_shingleroof jul10_watt1300 mar15_area mar15_lowqualityqoodfloor mar15_personaltoilet mar15_personalwater mar15_protectedwellwashwa mar15_woodwall pool11_concretewall jul07_mutualnotoilet jul07_publicwaterownershi jul07_shingleroof jul07_unitarea jul08_riverdrinkwater

***********************
** regresions **
***********************

di "Doing OLS regressions with selected controls."

// load in data
use "$codeddata/final_database_collapsed_sweights.dta", clear

*Shorten variable names so they match (keep first 25 characters)
foreach v of var * {
    local new = substr("`v'", 1, 25)
    quietly rename `v' `new'
}

areg own_flattv tr_tv tr_wc `flattv_controls', absorb(strata_orig) cluster(province) 
outreg2 using "$outpath/lasso_matlab.xls", replace se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

**********************************************************************
** lasso selected variables with weights (r=2 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls Mmar10_unmeteredPLNelectr jul10_electricity jul10_ownhouse jul10_shingleroof jul10_totalfemale mar10_totalmale mar15_airconditioner mar15_clayroof mar15_concreteroof mar15_int_other mar15_int_recreational mar15_landline mar15_marblegranitefloor mar15_month_pcexp mar15_vehicleinternet mar15_woodwall pool11_electricity pool11_month_exp pool11_ownhouse pool11_shingleroof pool11_telephone pool11_usagecert Mfeb07_noaccessdrinkwater jul07_month_pcexp jul07_n_hhmusecompint jul07_n_hhschoolinternet jul07_protwelldrinkwater jul08_asbestosroof jul08_n_hhlandlineforinte jul09_concreteroof jul09_homeforinternet jul09_n_hhhomeforinternet jul09_officeforinternet jul09_telephone jul09_watt2200higher mar08_month_pcexp mar09_shingleroof

local wcgoose_controls Mmar10_unmeteredPLNelectr Mpool11_mutualnotoilet jul10_concretewall jul10_shingleroof jul10_totalfemale mar10_mutualnotoilet mar10_totalmale mar15_bottleddrinkwater mar15_landline mar15_mutualnotoilet mar15_opendisposal mar15_personaltoilet mar15_publicwater pool11_personalnotoilet pool11_shingleroof Mfeb07_noaccessdrinkwater Mjul08_charcoal Mmar09_noaccesswater feb07_personalwater jul07_n_hhschoolinternet jul07_personalwaterowners mar08_noaccesstotoilet mar08_refilldrinkwater mar09_bottleddrinkwater mar09_otherelectricity mar09_shingleroof
 
local n_cell_controls Mmar10_unmeteredPLNelectr Mpool11_mutualnotoilet jul10_otherroof jul10_totalfemale mar10_unprotspringdrinkwa mar15_airconditioner mar15_boat mar15_bottleddrinkwater mar15_landline mar15_n_cell_hh mar15_unprotspringdrinkwa pool11_concretewall Mfeb07_noaccessdrinkwater Mmar09_noaccesswater jul07_n_hhwarnetinternet jul08_otherelectricity jul08_totalfemale jul09_watt2200higher
 
local total_room_controls Mmar10_unmeteredPLNelectr jul10_otherroof jul10_totalfemale mar10_unprotspringdrinkwa mar15_shinglewoodroof mar15_unprotspringdrinkwa Mfeb07_noaccessdrinkwater Mmar09_noaccesswater jul07_n_hhschoolinternet jul07_schoolforinternet jul08_totalfemale

***********************
** regresions **
***********************

di "Doing automatic (areg) WLS estimation"

// load in data
use "$codeddata/final_database_collapsed_sweights.dta", clear

*Shorten variable names so they match (keep first 25 characters)
foreach v of var * {
    local new = substr("`v'", 1, 25)
    quietly rename `v' `new'
}

areg own_flattv tr_tv tr_wc `flattv_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

**********************************************************************
** lasso selected variables without weights (r=3 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls feb07_asbestosroof feb07_goosetoilet jul07_month_pcexp jul07_telephone jul07_computerforinternet jul07_kerosene jul07_firewood jul08_telephone jul08_n_hhlandlineforinte jul08_riverdrinkwater mar09_mutualsquattoilet jul09_telephone jul09_officeforinternet jul09_ownhouse jul09_lease jul09_concreteroof jul09_watt2200higher jul09_firewood mar10_lease mar10_concreteroof jul10_n_hhcellphone jul10_totalfemale jul10_firewood pool11_telephone pool11_computer pool11_month_exp pool11_concreteroof pool11_electricity pool11_mutualsquattoilet pool12_airconditioner pool12_refrigerator pool12_car pool12_concreteroof pool12_protwelldrinkwater pool12_mutualwater pool12_watt2200higher pool12_electricity pool12_mutualsquattoilet pool13_n_hhcellphone pool13_usagecert pool13_marbleceramicfloor urban

local wcgoose_controls feb07_fiberpalmroof feb07_personalgoosetoilet jul07_personalgoosetoilet jul08_personalgoosetoilet mar09_personalgoosetoilet jul10_motorcycle jul10_totalfemale jul10_personalgoosetoilet pool11_refilldrinkwater pool11_riverdrinkwater pool11_personaltoilet pool12_fiberpalmroof pool12_septicdisposal pool12_personalgoosetoile pool14_pumpcookwater
 
local n_cell_controls feb07_publicwater jul07_area jul07_telephone jul07_cellphone jul07_concretewall jul07_firewood mar08_soilfloor jul08_telephone jul08_n_hhcellphone jul08_watt1300 mar09_unprotspringdrinkwa jul09_area jul09_cellphone mar10_buyingdrinkwater jul10_n_hhcellphone jul10_totalfemale jul10_septicdisposal jul10_watt1300 pool11_laptop pool11_marbleceramicfloor pool11_cleanwatersanitati pool11_personalwater pool12_n_hhcellphone pool12_concreteroof pool13_n_hhcellphone pool13_totalmale
 
local total_room_controls feb07_area jul07_area jul07_publicwaterownershi mar08_riverdrinkwater jul09_publictoilet jul10_totalfemale jul10_publictoilet pool11_shingleroof pool11_fiberpalmroof pool11_woodfloor pool11_protectedwellwashw pool11_personaltoilet pool11_watt900 pool12_shingleroof pool13_hhhouse3 pool13_shingleroof

***********************
** regresions **
***********************

di "Doing individual level OLS regression using LASSO controls"

// load in data
use "$codeddata/lasso_prepped_inds_temp1.dta", clear

areg own_flattv tr_tv tr_wc `flattv_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)


