*************************************************************
* Post-Lasso Regression for SUSENAS survey experiment
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off 

**********************************************************************
** lasso selected variables without weights (r=1 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls $NOWEIGHTS_TV_CONTROLS

local wcgoose_controls $NOWEIGHTS_WC_CONTROLS
 
local n_cell_controls $NOWEIGHTS_CELL_CONTROLS
 
local total_room_controls $NOWEIGHTS_ROOM_CONTROLS

***********************
** regresions **
***********************

di "Doing OLS regressions with selected controls."

// load in data
use "$codeddata/final_database_collapsed_sweights.dta", clear

*Shorten variable names so they match (keep first 25 characters)
foreach v of var * {
    local new = substr("`v'", 1, 25)
    quietly rename `v' `new'
}

areg own_flattv tr_tv tr_wc `flattv_controls', absorb(strata_orig) cluster(province) 
outreg2 using "$outpath/lasso_matlab.xls", replace se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

**********************************************************************
** lasso selected variables with weights (r=2 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls $WEIGHTS_TV_CONTROLS

local wcgoose_controls $WEIGHTS_WC_CONTROLS
 
local n_cell_controls $WEIGHTS_CELL_CONTROLS
 
local total_room_controls $WEIGHTS_ROOM_CONTROLS

***********************
** regresions **
***********************

di "Doing automatic (areg) WLS estimation"

// load in data
use "$codeddata/final_database_collapsed_sweights.dta", clear

*Shorten variable names so they match (keep first 25 characters)
foreach v of var * {
    local new = substr("`v'", 1, 25)
    quietly rename `v' `new'
}

areg own_flattv tr_tv tr_wc `flattv_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

**********************************************************************
** lasso selected variables without weights (r=3 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls mar10_personalsquattoilet jul10_computer jul10_lease jul10_personaltoilet jul10_watt2200 pool11_concreteroof pool11_soilfloor pool11_wattnometer pool11_electricity pool12_computer pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool12_electricity pool12_personalsquattoile pool12_mutualsquattoilet pool13_ownhouse pool13_watt2200 pool13_kerosene pool13_personalgoosetoile pool14_computer pool14_concreteroof pool14_bottledcookwater pool14_electricity mar15_cleandrinkwater mar15_publicinternet mar15_int_financial mar15_marblegranitefloor mar15_soilfloor mar15_personaltoilet mar15_notbuyingdrinkwater mar15_mutualsquattoilet feb07_concreteroof jul07_concreteroof jul08_landlineforinternet jul08_concreteroof jul09_homeforinternet jul09_n_hhotherinternet jul09_concreteroof jul09_personaltoilet jul09_watt2200higher jul09_personalsquattoilet urban

local wcgoose_controls jul10_bamboofloor jul10_squattoilet pool12_riverdrinkwater pool12_goosetoilet pool13_riverdrinkwater pool13_personalgoosetoile pool14_unprotspringdrinkw pool14_personalgoosetoile mar15_personaltoilet mar15_notbuyingdrinkwater mar15_nonelectricity mar15_personalsquattoilet mar15_publicsquattoilet feb07_otherelectricity mar08_otherroof mar08_personaltoilet mar09_riverdrinkwater mar09_otherelectricity
 
local n_cell_controls jul10_computer jul10_laptop jul10_lease pool11_soilfloor pool11_bottledwashwater pool12_computer pool12_concreteroof pool12_watt2200higher pool13_hhhouse4 pool14_bottledcookwater mar15_cleandrinkwater mar15_schoolinternet mar15_publicinternet mar15_int_financial mar15_personaltoilet mar15_protspringdrinkwate feb07_publicwater jul07_officeforinternet mar08_publicwater jul08_landlineforinternet jul08_lease jul08_watt2200higher mar09_rent jul09_energysource7 urban
 
local total_room_controls pool11_shingleroof pool12_residential pool13_woodfloor pool13_publicsquattoilet mar15_personaltoilet mar15_riverdrinkwater mar15_publicnotoilet

***********************
** regresions **
***********************

di "Doing individual level OLS regression using LASSO controls"

// load in data
use "$codeddata/lasso_prepped_inds_temp1.dta", clear

areg own_flattv tr_tv tr_wc `flattv_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)


