*************************************************************
* Post-Lasso Regression for SUSENAS survey experiment
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off 

**********************************************************************
** lasso selected variables without weights (r=1 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls $NOWEIGHTS_TV_CONTROLS

local wcgoose_controls $NOWEIGHTS_WC_CONTROLS
 
local n_cell_controls $NOWEIGHTS_CELL_CONTROLS
 
local total_room_controls $NOWEIGHTS_ROOM_CONTROLS

***********************
** regresions **
***********************

di "Doing OLS regressions with selected controls."

// load in data
use "$codeddata/final_database_collapsed_sweights.dta", clear

*Shorten variable names so they match (keep first 25 characters)
foreach v of var * {
    local new = substr("`v'", 1, 25)
    quietly rename `v' `new'
}

areg own_flattv tr_tv tr_wc `flattv_controls', absorb(strata_orig) cluster(province) 
outreg2 using "$outpath/lasso_matlab.xls", replace se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

**********************************************************************
** lasso selected variables with weights (r=2 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls $WEIGHTS_TV_CONTROLS

local wcgoose_controls $WEIGHTS_WC_CONTROLS
 
local n_cell_controls $WEIGHTS_CELL_CONTROLS
 
local total_room_controls $WEIGHTS_ROOM_CONTROLS

***********************
** regresions **
***********************

di "Doing automatic (areg) WLS estimation"

// load in data
use "$codeddata/final_database_collapsed_sweights.dta", clear

*Shorten variable names so they match (keep first 25 characters)
foreach v of var * {
    local new = substr("`v'", 1, 25)
    quietly rename `v' `new'
}

areg own_flattv tr_tv tr_wc `flattv_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls' [aw=group_size], absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Weighted, Group) keep(tr_tv tr_wc tr_cell tr_room)

**********************************************************************
** lasso selected variables without weights (r=3 in matlab script) **
**********************************************************************

***********************
** locals **
***********************

local flattv_controls mar10_concreteroof jul10_laptop jul10_lease jul10_watt2200 jul10_mutualsquattoilet pool11_lease pool11_personalgoosetoile pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool13_rent pool14_computer pool14_bottledcookwater pool14_refillcookwater mar15_cleandrinkwater mar15_officeinternet mar15_int_financial mar15_lease mar15_concreteroof mar15_marblegranitefloor mar15_refillwashwater jul07_lease jul07_concreteroof mar08_lease jul08_landlineforinternet jul08_asbestosroof jul09_homeforinternet jul09_personaltoilet jul09_watt2200 jul09_watt2200higher urban

local wcgoose_controls pool11_personalgoosetoile pool11_personalsquattoile pool12_personalsquattoile pool13_oillamp pool14_mutualsquattoilet mar15_personaltoilet mar15_noaccesswater mar15_personalunclosedpit feb07_notoilet jul07_publicnotoilet mar08_goosetoilet
 
local n_cell_controls jul10_lease pool11_soilfloor pool11_publicwater pool12_computer pool12_concreteroof pool14_computer pool14_bottledcookwater mar15_cleandrinkwater mar15_officeinternet mar15_publicinternet mar15_int_financial mar15_personaltoilet jul07_officeforinternet jul07_lease jul08_landlineforinternet mar09_rent urban
 
local total_room_controls jul10_parrafinlamp pool12_residential pool13_residential pool13_woodfloor pool13_riverdrinkwater mar15_personaltoilet mar15_riverdrinkwater jul07_publicnotoilet

***********************
** regresions **
***********************

di "Doing individual level OLS regression using LASSO controls"

// load in data
use "$codeddata/lasso_prepped_inds_temp1.dta", clear

areg own_flattv tr_tv tr_wc `flattv_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg own_wcgoose tr_tv tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg n_cell_hh tr_cell tr_room `n_cell_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)

areg total_room tr_cell tr_room `total_room_controls', absorb(strata_orig) cluster(province)
outreg2 using "$outpath/lasso_matlab.xls", append se excel cttop(Unweighted, Individual) keep(tr_tv tr_wc tr_cell tr_room)


