******************
*** Appendix Table 2: Randomization Check
******************

clear all
pause on
set more off

* save district level data 

foreach year in 2010 2011 2012 2014{

	use "$balance/coded/susenas`year'_v1.dta", clear
	
	/* code split of East Kalimantan into East and North Kalimantan
	gen     province_new = province
	replace province_new = 65 if province == 64 & district == 73 // Kota Tarakan
	replace province_new = 65 if province == 64 & district ==  7 // Kabupaten Bulungan
	replace province_new = 65 if province == 64 & district ==  6 // Kabupaten Malinau
	replace province_new = 65 if province == 64 & district ==  8 // Kabupaten Nunukan
	replace province_new = 65 if province == 64 & district == 10 // Kabupaten Tana Tidung

	rename province     province_old
	rename province_new province
	// */	
	* collapse to district level 
		gen obs=1
		if(`year'==2010){
			collapse (mean) urban hhsize homephone cellphone ncellowners ncellphone wcgoose         (rawsum) weight obs [aw=weight], by(province district)
			foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone wcgoose obs weight{
			rename `va' `va'`year'
			}
		}
		else{
			collapse (mean) urban hhsize homephone cellphone ncellowners ncellphone wcgoose cabletv (rawsum) weight obs [aw=weight], by(province district)
			foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone wcgoose cabletv obs weight{
			rename `va' `va'`year'
			}
		}
		
	save "$balance/temp/data_`year'", replace
}	
	
	
	
	
** load 2014
	use "$balance/coded/susenas2014_v1.dta", clear

	merge m:1 province district using "$balance/temp/data_2011"
	keep if _m==3
	drop _m
	
	merge m:1 province district using "$balance/temp/data_2012"
	keep if _m==3
	drop _m
		
	rename weight weight14
	
* merge back treatment status	
	merge m:1 province using "$balance/randomization/1506_treatmentPQ_inclpapua.dta", keepusing(treatP treatQ strata pair_id)
	keep if _m==3
	drop _m

** Save
saveold "$balance/temp/data_11_14_inclpapua", replace
	
	preserve
		keep province district
		duplicates drop
		gen sample = 1
		save "$balance/temp/sample_2014", replace
	restore

** label variables
label var urban "Urban"
label var hhsize "HH Size"
label var homephone "Homephone"
label var cellphone "Cellphone"
label var ncellowners "Nb. People with Cell Phones"
label var ncellphone "Nb. SIM Cards"
label var cabletv "Cable TV"
label var wcgoose "WC Goose"
label var treatP "WC"
label var treatQ "WC"

gen tr_WC = treatP
gen tr_TV = 1 - treatQ
gen tr_cell = 1 - tr_WC
label var tr_WC "WC Treatment"
label var tr_TV "TV Treatment"
label var tr_cell "Cell Treatment"

replace ncellowners = 0 if cellphone == 0 & missing(ncellowners)
replace ncellphone = 0 if cellphone == 0 & missing(ncellphone)

** 1. no controls
local i = 1
foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone cabletv wcgoose{

	areg `va' tr_TV tr_cell, ab(strata) cl(province)
	sum `va' if e(sample) == 1
	local all_mean `r(mean)'

	if `i' == 1 outreg2  using "$outpath/appendix_table2.doc", word replace dec(3) nocons nor2 label keep(tr_TV tr_cell) addstat(Dep. Var Mean, `all_mean') addtext(Strata FE, YES) title("Appendix Table 2: Randomization Check") addnote("Standard errors clustered at province level. SUSENAS March 2014 data is used. Dependent variable mean represents mean of dependent variable in entire sample.")
	if `i' != 1 outreg2  using "$outpath/appendix_table2.doc", word append dec(3) nocons nor2 label keep(tr_TV tr_cell) addstat(Dep. Var Mean, `all_mean') addtext(Strata FE, YES)

	local ++i
	
	}

*DONE!!!


