*****************
** Appendix Table 7a/7b Regressions
** (Table 2 with month/month-year FE )
*****************

clear
set more off

local table2_test = -0.95 // this value is taken from the highlighted figure in 20200629 table 2 calculations



** load in data
use "$codeddata/television_sales/coded_overall.dta", clear

** generate first tx variable
g treatdate = 1 if date>=ym(2015,6)
replace treatdate = 0 if treatdate == .
g treat = treatdate*treatgroup
g treat_cell1 = treatdate*tr_cell


** generate second tx variable
g treatdate2 = 1 if date >=ym(2015,8)
replace treatdate2 = 0 if treatdate2 == .
g treat2 = treatdate2*treatgroup
g treat_cell2 = treatdate2*tr_cell

** generate log of sales
g lnsales = ln(dataSalesUnits)
g lnvalue = ln(dataSalesValue)

** normalize by 2013-2014 average
g year = floor(date/12)+1960

for var lnsales lnvalue: bys group: egen temppremeanX = mean(X) if year == 2013 | year == 2014 \ bys group: egen premeanX = mean(temppremeanX) \ drop temppremeanX

for var lnsales lnvalue: g X_0 = X - premeanX

*** How many sales in control group after treatment
sum dataSalesUnits if date<=ym(2016,3) & !missing(date) & treatgroup == 0 & treatdate == 1
display `r(sum)' // 1.0 million after treatment, over 10 months = 0.10 per month

*** How many sales in treatment group before treatment
sum dataSalesUnits if date<=ym(2016,3) & !missing(date) & treatgroup == 1 & treatdate == 0
display `r(sum)' // 1.0 million after treatment, over 10 months = 0.10 per month

*** How many months before and after randomization?
preserve
	keep date treatdate 
	duplicates drop
	isid date
	tab treatdate
restore
tsset group date
//twoway line lnsales date, by(group) xline(663) xline(666) 

tsset group date
//twoway (line lnsales date if group == 1) (line lnsales date if group == 3) (line lnsales date if group == 2) (line lnsales date if group == 4), xline(663) xline(666) legend(label(1 "Treated 1")) legend(label(2 "Treated 3")) legend(label(3 "Control 2"))  legend(label(4 "Control 4")) title("log Sales in units")

for num 1/6: g lXlnsales = lX.lnsales

** label variables
label var lnsales "Log Sales"
label var treat "TV Treatment"
label var treat_cell1 "cell Treatment"

** generate triangular kernels
g w1_24 = max(1-abs((date-ym(2015,6)))/24,0)
g w1_18 = max(1-abs((date-ym(2015,6)))/18,0)
g w1_12 = max(1-abs((date-ym(2015,6)))/12,0)






//FIRST: month FE 
gen month = mod(date-(`=mofd(`=mdy(1,1,2013)')'), 12)+1

xi: reg lnsales treat treat_cell1 treatdate i.group*date i.month, robust
sum lnsales if e(sample) == 1
local control_mean: display %9.2f `r(mean)'
test treat = `table2_test'
local test_result: display %9.2f `r(F)'
local ptest: display %9.3f `r(p)'


outreg2 using "$outpath/table2_monthFE.doc", replace label keep(treat treat_cell1) se nocons nor2 title("Table 2: Effect of Treatments on Actual Television Sales -- ROBUSTNESS CHECKS") ///
addstat(Dep. Variable Mean, `control_mean', "Treat coeff = `table2_test' F-Statistic", `test_result', "Treat coeff = `table2_test' P-Value", `ptest') addtext(Model/Standard Errors, Robust, Group-Time Trends, YES)


xi: newey2 lnsales treat treat_cell1 treatdate i.group*date i.month, lag(3)
sum lnsales if e(sample) == 1
local control_mean: display %9.2f `r(mean)'
test treat = `table2_test'
local test_result: display %9.2f `r(F)'
local ptest: display %9.3f `r(p)'

outreg2 using "$outpath/table2_monthFE.doc", append label keep(treat treat_cell1) se nocons nor2 title("Table 2: Effect of Treatments on Actual Television Sales -- ROBUSTNESS CHECKS") ///
addstat(Dep. Variable Mean, `control_mean', "Treat coeff = `table2_test' F-Statistic", `test_result', "Treat coeff = `table2_test' P-Value", `ptest') addtext(Model/Standard Errors, Newey, Group-Time Trends, YES)


xi: xtpcse lnsales treat treat_cell1 treatdate i.group*date i.month, corr(ar1) 
sum lnsales if e(sample) == 1
local control_mean: display %9.2f `r(mean)'
test treat = `table2_test'
local test_result: display %9.2f `r(chi2)'
di "`test_result'"
local ptest: display %9.3f `r(p)'
di "`ptest'"


outreg2 using "$outpath/table2_monthFE.doc", append label keep(treat treat_cell1) se nocons nor2 title("Table 2: Effect of Treatments on Actual Television Sales -- ROBUSTNESS CHECKS") ///
addstat(Dep. Variable Mean, `control_mean', "Treat coeff = `table2_test' F-Statistic", `test_result', "Treat coeff = `table2_test' P-Value", `ptest') addtext(Model/Standard Errors, Panel-Corrected AR(1), Group-Time Trends, YES)



//SECOND: month-year FE 
xi: reg lnsales treat treat_cell1 treatdate i.group*date i.date, robust
sum lnsales if e(sample) == 1
local control_mean: display %9.2f `r(mean)'
test treat = `table2_test'
local test_result: display %9.2f `r(F)'
local ptest: display %9.3f `r(p)'


outreg2 using "$outpath/table2_monthyearFE.doc", replace label keep(treat treat_cell1) se nocons nor2 title("Table 2: Effect of Treatments on Actual Television Sales -- ROBUSTNESS CHECKS") ///
addstat(Dep. Variable Mean, `control_mean', "Treat coeff = `table2_test' F-Statistic", `test_result', "Treat coeff = `table2_test' P-Value", `ptest') addtext(Model/Standard Errors, Robust, Group-Time Trends, YES)


xi: newey2 lnsales treat treat_cell1 treatdate i.group*date i.date, lag(3)
sum lnsales if e(sample) == 1
local control_mean: display %9.2f `r(mean)'
test treat = `table2_test'
local test_result: display %9.2f `r(F)'
local ptest: display %9.3f `r(p)'

outreg2 using "$outpath/table2_monthyearFE.doc", append label keep(treat treat_cell1) se nocons nor2 title("Table 2: Effect of Treatments on Actual Television Sales -- ROBUSTNESS CHECKS") ///
addstat(Dep. Variable Mean, `control_mean', "Treat coeff = `table2_test' F-Statistic", `test_result', "Treat coeff = `table2_test' P-Value", `ptest') addtext(Model/Standard Errors, Newey, Group-Time Trends, YES)


xi: xtpcse lnsales treat treat_cell1 treatdate i.group*date i.date, corr(ar1) 
sum lnsales if e(sample) == 1
local control_mean: display %9.2f `r(mean)'
test treat = `table2_test'
local test_result: display %9.2f `r(chi2)'
di "`test_result'"
local ptest: display %9.3f `r(p)'
di "`ptest'"


outreg2 using "$outpath/table2_monthyearFE.doc", append label keep(treat treat_cell1) se nocons nor2 title("Table 2: Effect of Treatments on Actual Television Sales -- ROBUSTNESS CHECKS") ///
addstat(Dep. Variable Mean, `control_mean', "Treat coeff = `table2_test' F-Statistic", `test_result', "Treat coeff = `table2_test' P-Value", `ptest') addtext(Model/Standard Errors, Panel-Corrected AR(1), Group-Time Trends, YES)



