*****************
** Appendix Table 9-10 Regressions
** (Table 3 with all years pooled)
*****************

clear
set more off

use "$codeddata/telephone_sales/coded_all.dta", clear

*************************************
* Running basic regression
*************************************

** label variables
label var ln_subscribers "Log Subscribers"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

local exp_vars_cell_room tr_cell tr_tv




reg ln_subscribers `exp_vars_cell_room', robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table9.doc", replace se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, N, Strata FE, N) title("Table 3: Effect of Treatments on SIM Card Ownership, All Years") ///
addnote("Dependent variable mean represents mean of dependent variable in entire sample. SIM Card data contains data on number of prepaid and postpaid active subscribers by province (kabupaten is only partially provided) and provider.")

reg ln_subscribers `exp_vars_cell_room' ln_pop, robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table9.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, N)

areg ln_subscribers `exp_vars_cell_room' ln_pop, absorb(strata_orig) robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table9.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, Y)




*** ROBUSTNESS CHECK: drop Jakarta

drop if provice_str == "DKI JAKARTA"



reg ln_subscribers `exp_vars_cell_room', robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table10.doc", replace se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, N, Strata FE, N) title("Appendix Table 6: Effect of Treatments on SIM Card Ownership, All Years -- Robustness Check: Dropped Jakarta") ///
addnote("Dependent variable mean represents mean of dependent variable in entire sample. SIM Card data contains data on number of prepaid and postpaid active subscribers by province (kabupaten is only partially provided) and provider.")

reg ln_subscribers `exp_vars_cell_room' ln_pop, robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table10.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, N)

areg ln_subscribers `exp_vars_cell_room' ln_pop, absorb(strata_orig) robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table10.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, Y)


*DONE!


