*************************************************************
* OLS
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off
clear

** convert to dta file
shp2dta using "$rundir/data/map/adminshp/IDN_adm1", data("$rundir/data/map/clean/admin1_data") coor("$rundir/data/map/clean/admin1_coordinates") replace

** load in data
use "$rundir/data/map/clean/admin1_data", clear
rename NAME_1 province

** make sure these are correct:
replace province = "Bangka Belitung" if province == "Bangka-Belitung"
replace province = "DKI Jakarta" if province == "Jakarta Raya"
replace province = "DI Yogyakarta" if province == "Yogyakarta"
replace province = "Nanggroe Aceh Darussalam" if province == "Aceh"
replace province = "Papua Barat" if province == "Irian Jaya Barat"

** merge with treatment assignment
merge 1:1 province using "$rawdata/randomization/Randomization.dta", gen(prov_merge)

** need to find borders for the 34th (new) province! North Kalimantan
replace ID_1 = 34 if province == "Kalimantan Utara"
replace _ID = 34 if province == "Kalimantan Utara"
isid ID_1
isid _ID
replace ID_0 = 106 if province == "Kalimantan Utara"
replace ISO = "IDN" if province == "Kalimantan Utara"
replace NAME_0 = "Indonesia" if province == "Kalimantan Utara"

** label treatment variable
egen tx_group = group(treatment)
label define treatment 1 "Cell, TV" 2 "Cell, Room" 3 "WC, TV" 4 "WC, Room"
label values tx_group treatment

** save map data
save "$rundir/data/map/clean/admin1_data", replace

** create map and export as png
spmap tx_group using "$rundir/data/map/clean/admin1_coordinates", title("Figure 1: Map of Randomization", size(*0.9)) id(_ID) ocolor(black) osize(thin) ///
clmethod(custom) clbreaks(0 1 2 3 4) fcolor(Pastel1)  ///
legend(label(1 "Not in randomization") label(2 "TV, Cell" ) label(3 "Room, Cell" )  label(4 "TV, WC" )  label(5 "Room, WC" )) ///
scalebar(units(5) label(500 km))
graph export "$outpath/figure1.png", replace

** NOTE: since the 34th province is new, we then needed to manually draw it.
** NOTE: it was saved as "figure1_revised.png"


*DONE!



