******************
*** Appendix Table 2: Randomization Check
******************

clear all
pause on
set more off

* save district level data 

foreach year in 2010 2011 2012 2014{

	use "$balance/coded/susenas`year'_v1.dta", clear
	
	/* code split of East Kalimantan into East and North Kalimantan
	gen     province_new = province
	replace province_new = 65 if province == 64 & district == 73 // Kota Tarakan
	replace province_new = 65 if province == 64 & district ==  7 // Kabupaten Bulungan
	replace province_new = 65 if province == 64 & district ==  6 // Kabupaten Malinau
	replace province_new = 65 if province == 64 & district ==  8 // Kabupaten Nunukan
	replace province_new = 65 if province == 64 & district == 10 // Kabupaten Tana Tidung

	rename province     province_old
	rename province_new province
	// */	
	* collapse to district level 
		gen obs=1
		if(`year'==2010){
			collapse (mean) urban hhsize homephone cellphone ncellowners ncellphone wcgoose         (rawsum) weight obs [aw=weight], by(province district)
			foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone wcgoose obs weight{
			rename `va' `va'`year'
			}
		}
		else{
			collapse (mean) urban hhsize homephone cellphone ncellowners ncellphone wcgoose cabletv (rawsum) weight obs [aw=weight], by(province district)
			foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone wcgoose cabletv obs weight{
			rename `va' `va'`year'
			}
		}
		
	save "$balance/temp/data_`year'", replace
}	
	
	
	
	
** load 2014
	use "$balance/coded/susenas2014_v1.dta", clear

	merge m:1 province district using "$balance/temp/data_2011"
	keep if _m==3
	drop _m
	
	merge m:1 province district using "$balance/temp/data_2012"
	keep if _m==3
	drop _m
		
	rename weight weight14
	
* merge back treatment status	
	merge m:1 province using "$balance/randomization/1506_treatmentPQ_inclpapua.dta", keepusing(treatP treatQ strata pair_id)
	keep if _m==3
	drop _m

** Save
saveold "$balance/temp/data_11_14_inclpapua", replace
	
	preserve
		keep province district
		duplicates drop
		gen sample = 1
		save "$balance/temp/sample_2014", replace
	restore

** label variables
label var urban "Urban"
label var hhsize "HH Size"
label var homephone "Homephone"
label var cellphone "Cellphone"
label var ncellowners "Nb. People with Cell Phones"
label var ncellphone "Nb. SIM Cards"
label var cabletv "Cable TV"
label var wcgoose "WC Goose"
label var treatP "WC"
label var treatQ "WC"

gen tr_WC = treatP
gen tr_TV = 1 - treatQ
gen tr_cell = 1 - tr_WC
label var tr_WC "WC Treatment"
label var tr_TV "TV Treatment"
label var tr_cell "Cell Treatment"

replace ncellowners = 0 if cellphone == 0 & missing(ncellowners)
replace ncellphone = 0 if cellphone == 0 & missing(ncellphone)

** 1. no controls
local i = 1
foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone cabletv wcgoose{

	areg `va' tr_TV tr_cell, ab(strata) cl(province)
	sum `va' if e(sample) == 1
	local all_mean `r(mean)'
	local actual_tv_`va' = _b[tr_TV]
	local actual_cell_`va' = _b[tr_cell]


	if `i' == 1 outreg2  using "$outpath/appendix_table2.doc", word replace dec(3) nocons nor2 label keep(tr_TV tr_cell) addstat(Dep. Var Mean, `all_mean') addtext(Strata FE, YES) title("Appendix Table 2: Randomization Check") addnote("Standard errors clustered at province level. SUSENAS March 2014 data is used. Dependent variable mean represents mean of dependent variable in entire sample.")
	if `i' != 1 outreg2  using "$outpath/appendix_table2.doc", word append dec(3) nocons nor2 label keep(tr_TV tr_cell) addstat(Dep. Var Mean, `all_mean') addtext(Strata FE, YES)

	local ++i
	
	}

*************************************
****** RANDOMIZATION INFERENCE ******
*************************************

*merge with random treatments // SMS: I had to add this in here. I followed our randomization procedure to create these placebo treatments.
merge m:1 province using "$fake_tx/fake_tx.dta", nogen assert(2 3) keep (3)

local counter_tv_urban = 0
local counter_tv_hhsize = 0
local counter_tv_homephone = 0
local counter_tv_cellphone = 0
local counter_tv_ncellowners = 0
local counter_tv_ncellphone = 0
local counter_tv_cabletv = 0
local counter_tv_wcgoose = 0

local counter_cell_urban = 0
local counter_cell_hhsize = 0
local counter_cell_homephone = 0
local counter_cell_cellphone = 0
local counter_cell_ncellowners = 0
local counter_cell_ncellphone = 0
local counter_cell_cabletv = 0
local counter_cell_wcgoose = 0

local nb_iter = 1000

** loop over fake randomizations
forv i = 1/`nb_iter' {

    gen tr_cell_`i' = 1 - tr_wc_`i'

    foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone cabletv wcgoose {

		areg `va' tr_tv_`i' tr_cell_`i', ab(strata) cl(province)

		local ri_coef_1 = _b[tr_tv_`i']
		if abs(`ri_coef_1') > abs(`actual_tv_`va'') local counter_tv_`va' = `counter_tv_`va'' + 1

		local ri_coef_2 = _b[tr_cell_`i']
		if abs(`ri_coef_2') > abs(`actual_cell_`va'') local counter_cell_`va' = `counter_cell_`va'' + 1

}

    drop *_`i'

}


foreach va of varlist urban hhsize homephone cellphone ncellowners ncellphone cabletv wcgoose {

di "`va'"

local ri_pval_tv_`va' = `counter_tv_`va'' / `nb_iter'
di "******* tv... `ri_pval_tv_`va''"
local ri_pval_cell_`va' = `counter_cell_`va'' / `nb_iter'
di "******* cell... `ri_pval_cell_`va''"

}

*** export results!!!
#delimit ;
matrix pval_table1_RI = (`ri_pval_tv_urban', `ri_pval_tv_hhsize', `ri_pval_tv_homephone', `ri_pval_tv_cellphone', `ri_pval_tv_ncellowners', `ri_pval_tv_ncellphone', `ri_pval_tv_cabletv', `ri_pval_tv_wcgoose'
\ `ri_pval_cell_urban', `ri_pval_cell_hhsize', `ri_pval_cell_homephone', `ri_pval_cell_cellphone', `ri_pval_cell_ncellowners', `ri_pval_cell_ncellphone', `ri_pval_cell_cabletv', `ri_pval_cell_wcgoose');
#delimit cr
matrix list pval_table1_RI
clear
matrix list pval_table1_RI
svmat pval_table1_RI
export delimited using "$outpath/appendixtable2_ri_pval.csv", replace



*DONE!!!


