*****************
** Table 3 Regressions
*****************

clear
set more off

use "$codeddata/telephone_sales/coded_all.dta", clear

** DROP JAKARTA
drop if provice_str == "DKI JAKARTA"

*************************************
* Running basic regression
*************************************

** label variables
label var ln_subscribers "Log Subscribers"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

local exp_vars_cell_room tr_cell tr_tv

forvalues year = 2015/2017 {

reg ln_subscribers `exp_vars_cell_room' if year==`year', robust
local actual_1_`year' = _b[tr_cell]
local actual_1b_`year' = _b[tr_tv]

reg ln_subscribers `exp_vars_cell_room' ln_pop if year==`year', robust
local actual_2_`year' = _b[tr_cell]
local actual_2b_`year' = _b[tr_tv]

areg ln_subscribers `exp_vars_cell_room' ln_pop if year==`year', absorb(strata_orig) robust
local actual_3_`year' = _b[tr_cell]
local actual_3b_`year' = _b[tr_tv]

local counter1_`year' = 0
local counter2_`year' = 0
local counter3_`year' = 0

local counter1b_`year' = 0
local counter2b_`year' = 0
local counter3b_`year' = 0

}

*************************************
****** RANDOMIZATION INFERENCE ******
*************************************

*merge with random treatments // SMS: I had to add this in here. I followed our randomization procedure to create these placebo treatments.
merge m:1 province using "$fake_tx/fake_tx.dta", nogen assert(2 3) keep(3) force

local nb_iter = 1000

** loop over fake randomizations
forv i = 1/`nb_iter' {

    gen tr_cell_`i' = 1 - tr_wc_`i'
    gen tr_room_`i' = 1 - tr_tv_`i'

forvalues year = 2015/2017 {

	reg ln_subscribers tr_cell_`i' tr_tv_`i' if year==`year', robust
	local ri_coef_1 = _b[tr_cell_`i']
	if abs(`ri_coef_1') > abs(`actual_1_`year'') local counter1_`year' = `counter1_`year'' + 1
	local ri_coef_1b = _b[tr_tv_`i']
	if abs(`ri_coef_1b') > abs(`actual_1b_`year'') local counter1b_`year' = `counter1b_`year'' + 1

	reg ln_subscribers tr_cell_`i' tr_tv_`i' ln_pop if year==`year', robust
	local ri_coef_2 = _b[tr_cell_`i']
	if abs(`ri_coef_2') > abs(`actual_2_`year'') local counter2_`year' = `counter2_`year'' + 1
	local ri_coef_2b = _b[tr_tv_`i']
	if abs(`ri_coef_2b') > abs(`actual_2b_`year'') local counter2b_`year' = `counter2b_`year'' + 1

	areg ln_subscribers tr_cell_`i' tr_tv_`i' ln_pop if year==`year', absorb(strata_orig) robust
	local ri_coef_3 = _b[tr_cell_`i']
	if abs(`ri_coef_3') > abs(`actual_3_`year'') local counter3_`year' = `counter3_`year'' + 1
	local ri_coef_3b = _b[tr_tv_`i']
	if abs(`ri_coef_3b') > abs(`actual_3b_`year'') local counter3b_`year' = `counter3b_`year'' + 1

}

    drop *_`i'
}

** compute p-values 
forvalues year = 2015/2017 {

	local ri_pval1_`year' = `counter1_`year'' / `nb_iter'
	di "********** `ri_pval1_`year'' ********"
	local ri_pval2_`year' = `counter2_`year'' / `nb_iter'
	di "********** `ri_pval2_`year'' ********"
	local ri_pval3_`year' = `counter3_`year'' / `nb_iter'
	di "********** `ri_pval3_`year'' ********"

	local ri_pval1b_`year' = `counter1b_`year'' / `nb_iter'
	di "********** `ri_pval1b_`year'' ********"
	local ri_pval2b_`year' = `counter2b_`year'' / `nb_iter'
	di "********** `ri_pval2b_`year'' ********"
	local ri_pval3b_`year' = `counter3b_`year'' / `nb_iter'
	di "********** `ri_pval3b_`year'' ********"

}

*** export results!!!
#delimit ;
matrix pval_table3_RI = (`ri_pval1_2015', `ri_pval2_2015', `ri_pval3_2015' \
`ri_pval1_2016', `ri_pval2_2016', `ri_pval3_2016' \
`ri_pval1_2017', `ri_pval2_2017', `ri_pval3_2017');
matrix pval_table3_RIb = (`ri_pval1b_2015', `ri_pval2b_2015', `ri_pval3b_2015' \
`ri_pval1b_2016', `ri_pval2b_2016', `ri_pval3b_2016' \
`ri_pval1b_2017', `ri_pval2b_2017', `ri_pval3b_2017');
#delimit cr
matrix list pval_table3_RI
matrix list pval_table3_RIb
clear
matrix list pval_table3_RI
matrix list pval_table3_RIb
svmat pval_table3_RI
export delimited using "$outpath/appendix_table8_ri_pval.csv", replace
clear
svmat pval_table3_RIb
export delimited using "$outpath/appendix_table8b_ri_pval.csv", replace






*DONE!


