*****************
** Appendix Table 9-10 Regressions
** (Table 3 with all years pooled)
*****************

clear
set more off

use "$codeddata/telephone_sales/coded_all.dta", clear

*************************************
* Running basic regression
*************************************

** label variables
label var ln_subscribers "Log Subscribers"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

local exp_vars_cell_room tr_cell tr_tv

reg ln_subscribers `exp_vars_cell_room', robust
local actual_1 = _b[tr_cell]
local actual_1b = _b[tr_tv]

reg ln_subscribers `exp_vars_cell_room' ln_pop, robust
local actual_2 = _b[tr_cell]
local actual_2b = _b[tr_tv]

areg ln_subscribers `exp_vars_cell_room' ln_pop, absorb(strata_orig) robust
local actual_3 = _b[tr_cell]
local actual_3b = _b[tr_tv]

local counter1 = 0
local counter2 = 0
local counter3 = 0

local counter1b = 0
local counter2b = 0
local counter3b = 0


*************************************
****** RANDOMIZATION INFERENCE ******
*************************************
*merge with random treatments // SMS: I had to add this in here. I followed our randomization procedure to create these placebo treatments.
merge m:1 province using "$fake_tx/fake_tx.dta", nogen assert(2 3) keep(3) force

local nb_iter = 1000



** loop over fake randomizations
forv i = 1/`nb_iter' {

    gen tr_cell_`i' = 1 - tr_wc_`i'
    gen tr_room_`i' = 1 - tr_tv_`i'

	reg ln_subscribers tr_cell_`i' tr_tv_`i', robust
	local ri_coef_1 = _b[tr_cell_`i']
	if abs(`ri_coef_1') > abs(`actual_1') local counter1 = `counter1' + 1
	local ri_coef_1b = _b[tr_tv_`i']
	if abs(`ri_coef_1b') > abs(`actual_1b') local counter1b = `counter1b' + 1

	reg ln_subscribers tr_cell_`i' tr_tv_`i' ln_pop, robust
	local ri_coef_2 = _b[tr_cell_`i']
	if abs(`ri_coef_2') > abs(`actual_2') local counter2 = `counter2' + 1
	local ri_coef_2b = _b[tr_tv_`i']
	if abs(`ri_coef_2b') > abs(`actual_2b') local counter2b = `counter2b' + 1

	areg ln_subscribers tr_cell_`i' tr_tv_`i' ln_pop, absorb(strata_orig) robust
	local ri_coef_3 = _b[tr_cell_`i']
	if abs(`ri_coef_3') > abs(`actual_3') local counter3 = `counter3' + 1
	local ri_coef_3b = _b[tr_tv_`i']
	if abs(`ri_coef_3b') > abs(`actual_3b') local counter3b = `counter3b' + 1

    drop *_`i'
}

** compute p-values 

local ri_pval1 = `counter1' / `nb_iter'
di "********** `ri_pval1' ********"
local ri_pval2 = `counter2' / `nb_iter'
di "********** `ri_pval2' ********"
local ri_pval3 = `counter3' / `nb_iter'
di "********** `ri_pval3' ********"

local ri_pval1b = `counter1b' / `nb_iter'
di "********** `ri_pval1b' ********"
local ri_pval2b = `counter2b' / `nb_iter'
di "********** `ri_pval2b' ********"
local ri_pval3b = `counter3b' / `nb_iter'
di "********** `ri_pval3b' ********"


*** export results!!!
#delimit ;
matrix pval_appendixtable9_RI = (`ri_pval1', `ri_pval2', `ri_pval3');
matrix pval_appendixtable9_RIb = (`ri_pval1b', `ri_pval2b', `ri_pval3b');
#delimit cr
matrix list pval_appendixtable9_RI
matrix list pval_appendixtable9_RIb
clear
matrix list pval_appendixtable9_RI
matrix list pval_appendixtable9_RIb
svmat pval_appendixtable9_RI
export delimited using "$outpath/appendix_table9_ri_pval.csv", replace
clear
svmat pval_appendixtable9_RIb
export delimited using "$outpath/appendix_table9b_ri_pval.csv", replace




*** ROBUSTNESS CHECK: drop Jakarta
use "$codeddata/telephone_sales/coded_all.dta", clear

drop if provice_str == "DKI JAKARTA"

*************************************
* Running basic regression
*************************************

** label variables
label var ln_subscribers "Log Subscribers"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

local exp_vars_cell_room tr_cell tr_tv

reg ln_subscribers `exp_vars_cell_room', robust
local actual_1 = _b[tr_cell]
local actual_1b = _b[tr_tv]

reg ln_subscribers `exp_vars_cell_room' ln_pop, robust
local actual_2 = _b[tr_cell]
local actual_2b = _b[tr_tv]

areg ln_subscribers `exp_vars_cell_room' ln_pop, absorb(strata_orig) robust
local actual_3 = _b[tr_cell]
local actual_3b = _b[tr_tv]

local counter1 = 0
local counter2 = 0
local counter3 = 0

local counter1b = 0
local counter2b = 0
local counter3b = 0


*************************************
****** RANDOMIZATION INFERENCE ******
*************************************
*merge with random treatments // SMS: I had to add this in here. I followed our randomization procedure to create these placebo treatments.
merge m:1 province using "$fake_tx/fake_tx.dta", nogen assert(2 3) keep(3) force

local nb_iter = 1000



** loop over fake randomizations
forv i = 1/`nb_iter' {

    gen tr_cell_`i' = 1 - tr_wc_`i'
    gen tr_room_`i' = 1 - tr_tv_`i'

	reg ln_subscribers tr_cell_`i' tr_tv_`i', robust
	local ri_coef_1 = _b[tr_cell_`i']
	if abs(`ri_coef_1') > abs(`actual_1') local counter1 = `counter1' + 1
	local ri_coef_1b = _b[tr_tv_`i']
	if abs(`ri_coef_1b') > abs(`actual_1b') local counter1b = `counter1b' + 1

	reg ln_subscribers tr_cell_`i' tr_tv_`i' ln_pop, robust
	local ri_coef_2 = _b[tr_cell_`i']
	if abs(`ri_coef_2') > abs(`actual_2') local counter2 = `counter2' + 1
	local ri_coef_2b = _b[tr_tv_`i']
	if abs(`ri_coef_2b') > abs(`actual_2b') local counter2b = `counter2b' + 1

	areg ln_subscribers tr_cell_`i' tr_tv_`i' ln_pop, absorb(strata_orig) robust
	local ri_coef_3 = _b[tr_cell_`i']
	if abs(`ri_coef_3') > abs(`actual_3') local counter3 = `counter3' + 1
	local ri_coef_3b = _b[tr_tv_`i']
	if abs(`ri_coef_3b') > abs(`actual_3b') local counter3b = `counter3b' + 1

    drop *_`i'
}

** compute p-values 

local ri_pval1 = `counter1' / `nb_iter'
di "********** `ri_pval1' ********"
local ri_pval2 = `counter2' / `nb_iter'
di "********** `ri_pval2' ********"
local ri_pval3 = `counter3' / `nb_iter'
di "********** `ri_pval3' ********"

local ri_pval1b = `counter1b' / `nb_iter'
di "********** `ri_pval1b' ********"
local ri_pval2b = `counter2b' / `nb_iter'
di "********** `ri_pval2b' ********"
local ri_pval3b = `counter3b' / `nb_iter'
di "********** `ri_pval3b' ********"


*** export results!!!
#delimit ;
matrix pval_appendixtable10_RI = (`ri_pval1', `ri_pval2', `ri_pval3');
matrix pval_appendixtable10_RIb = (`ri_pval1b', `ri_pval2b', `ri_pval3b');
#delimit cr
matrix list pval_appendixtable10_RI
matrix list pval_appendixtable10_RIb
clear
matrix list pval_appendixtable10_RI
matrix list pval_appendixtable10_RIb
svmat pval_appendixtable10_RI
export delimited using "$outpath/appendix_table10_ri_pval.csv", replace
clear
svmat pval_appendixtable10_RIb
export delimited using "$outpath/appendix_table10b_ri_pval.csv", replace


