*************************************************************
* OLS
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off
clear

* Load data (using imputed data, even though no controls for this first set so does not matter)
use "$codeddata/180529_final_database_imputem_2016susenas.dta", clear

*merge with random treatments // these are the same random treatments as is used for the FWER
rename province province_string
rename code province
merge m:1 province using "$fake_tx/fake_tx.dta", force nogen assert(match)

*************************************************************
** Label variables **
*************************************************************

label var own_flattv "Own TV"
label var own_wcgoose "Own WC"
label var total_room "Nb. Rooms"
label var n_cell_hh "Nb. SIM Cards"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

** lasso controls ** note: these are taken from matlabregressions.do, case r = 3 in the matlab script
local flattv_controls mar10_personalsquattoilet jul10_computer jul10_lease jul10_personaltoilet jul10_watt2200 pool11_concreteroof pool11_soilfloor pool11_wattnometer pool11_electricity pool12_computer pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool12_electricity pool12_personalsquattoile pool12_mutualsquattoilet pool13_ownhouse pool13_watt2200 pool13_kerosene pool13_personalgoosetoile pool14_computer pool14_concreteroof pool14_bottledcookwater pool14_electricity mar15_cleandrinkwater mar15_publicinternet mar15_int_financial mar15_marblegranitefloor mar15_soilfloor mar15_personaltoilet mar15_notbuyingdrinkwater mar15_mutualsquattoilet feb07_concreteroof jul07_concreteroof jul08_landlineforinternet jul08_concreteroof jul09_homeforinternet jul09_n_hhotherinternet jul09_concreteroof jul09_personaltoilet jul09_watt2200higher jul09_personalsquattoilet urban
local wcgoose_controls jul10_bamboofloor jul10_squattoilet pool12_riverdrinkwater pool12_goosetoilet pool13_riverdrinkwater pool13_personalgoosetoile pool14_unprotspringdrinkw pool14_personalgoosetoile mar15_personaltoilet mar15_notbuyingdrinkwater mar15_nonelectricity mar15_personalsquattoilet mar15_publicsquattoilet feb07_otherelectricity mar08_otherroof mar08_personaltoilet mar09_riverdrinkwater mar09_otherelectricity
local n_cell_controls jul10_computer jul10_bamboofloor pool11_concreteroof pool11_soilfloor pool12_computer pool12_concreteroof pool13_hhhouse4 pool14_computer pool14_bottledcookwater pool14_refillcookwater mar15_cleandrinkwater mar15_schoolinternet mar15_publicinternet mar15_personaltoilet feb07_publicwater jul07_officeforinternet mar08_publicwater jul08_landlineforinternet mar09_rent jul09_watt2200higher urban
local total_room_controls pool11_shingleroof pool12_residential pool13_woodfloor pool13_publicsquattoilet mar15_personaltoilet mar15_riverdrinkwater mar15_publicnotoilet

local nb_iter = 1000

*************************************************************
** 1. no controls **
*************************************************************

* No controls:
areg own_flattv tr_tv tr_cell , absorb(strata_orig) cluster(province)
local actual_1a = _b[tr_tv]
local actual_1b = _b[tr_cell]

* No controls:
areg n_cell_hh tr_tv tr_cell , absorb(strata_orig) cluster(province)
local actual_2a = _b[tr_tv]
local actual_2b = _b[tr_cell]

* No controls:
areg total_room tr_room tr_wc , absorb(strata_orig) cluster(province)
local actual_3a = _b[tr_room]
local actual_3b = _b[tr_wc]

* No controls:
areg own_wcgoose tr_room tr_wc , absorb(strata_orig) cluster(province)
local actual_4a = _b[tr_room]
local actual_4b = _b[tr_wc]

*************************************************************
** 2. lasso controls **
*************************************************************

* Lasso controls:
areg own_flattv tr_tv tr_cell `flattv_controls', absorb(strata_orig) cluster(province)
local lasso_1a = _b[tr_tv]
local lasso_1b = _b[tr_cell]

* Lasso controls:
areg n_cell_hh tr_tv tr_cell `n_cell_controls', absorb(strata_orig) cluster(province)
local lasso_2a = _b[tr_tv]
local lasso_2b = _b[tr_cell]

* Lasso controls:
areg total_room tr_room tr_wc `total_room_controls', absorb(strata_orig) cluster(province)
local lasso_3a = _b[tr_room]
local lasso_3b = _b[tr_wc]

* Lasso controls:
areg own_wcgoose tr_room tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
local lasso_4a = _b[tr_room]
local lasso_4b = _b[tr_wc]

*************************************************************
** 3. start RI **
*************************************************************

local counter1a = 0
local counter2a = 0
local counter3a = 0
local counter4a = 0
local counter5a = 0
local counter6a = 0
local counter7a = 0
local counter8a = 0
local counter1b = 0
local counter2b = 0
local counter3b = 0
local counter4b = 0
local counter5b = 0
local counter6b = 0
local counter7b = 0
local counter8b = 0

** loop over fake randomizations
forv i = 1/`nb_iter' {

    gen tr_cell_`i' = 1 - tr_wc_`i'
    gen tr_room_`i' = 1 - tr_tv_`i'

    *** no controls ***
	areg own_flattv tr_tv_`i' tr_cell_`i', absorb(strata_orig) cluster(province)
	if abs(_b[tr_tv_`i']) > abs(`actual_1a') local counter1a = `counter1a' + 1
	if abs(_b[tr_cell_`i']) > abs(`actual_1b') local counter1b = `counter1b' + 1

	areg n_cell_hh tr_tv_`i' tr_cell_`i' , absorb(strata_orig) cluster(province)
	if abs(_b[tr_tv_`i']) > abs(`actual_2a') local counter2a = `counter2a' + 1
	if abs(_b[tr_cell_`i']) > abs(`actual_2b') local counter2b = `counter2b' + 1

	areg total_room tr_room_`i' tr_wc_`i' , absorb(strata_orig) cluster(province)
	if abs(_b[tr_room_`i']) > abs(`actual_3a') local counter3a = `counter3a' + 1
	if abs(_b[tr_wc_`i']) > abs(`actual_3b') local counter3b = `counter3b' + 1

	areg own_wcgoose tr_room_`i' tr_wc_`i' , absorb(strata_orig) cluster(province)
	if abs(_b[tr_room_`i']) > abs(`actual_4a') local counter4a = `counter4a' + 1
	if abs(_b[tr_wc_`i']) > abs(`actual_4b') local counter4b = `counter4b' + 1

    *** lasso controls ***
	areg own_flattv tr_tv_`i' tr_cell_`i' `flattv_controls', absorb(strata_orig) cluster(province)
	if abs(_b[tr_tv_`i']) > abs(`lasso_1a') local counter5a = `counter5a' + 1
	if abs(_b[tr_cell_`i']) > abs(`lasso_1b') local counter5b = `counter5b' + 1

	areg n_cell_hh tr_tv_`i' tr_cell_`i' `n_cell_controls', absorb(strata_orig) cluster(province)
	if abs(_b[tr_tv_`i']) > abs(`lasso_2a') local counter6a = `counter6a' + 1
	if abs(_b[tr_cell_`i']) > abs(`lasso_2b') local counter6b = `counter6b' + 1

	areg total_room tr_room_`i' tr_wc_`i' `total_room_controls', absorb(strata_orig) cluster(province)
	if abs(_b[tr_room_`i']) > abs(`lasso_3a') local counter7a = `counter7a' + 1
	if abs(_b[tr_wc_`i']) > abs(`lasso_3b') local counter7b = `counter7b' + 1

	areg own_wcgoose tr_room_`i' tr_wc_`i' `wcgoose_controls', absorb(strata_orig) cluster(province)
	if abs(_b[tr_room_`i']) > abs(`lasso_4a') local counter8a = `counter8a' + 1
	if abs(_b[tr_wc_`i']) > abs(`lasso_4b') local counter8b = `counter8b' + 1

    drop *_`i'

}

local ri_pval1a = `counter1a' / `nb_iter'
local ri_pval2a = `counter2a' / `nb_iter'
local ri_pval3a = `counter3a' / `nb_iter'
local ri_pval4a = `counter4a' / `nb_iter'
local ri_pval5a = `counter5a' / `nb_iter'
local ri_pval6a = `counter6a' / `nb_iter'
local ri_pval7a = `counter7a' / `nb_iter'
local ri_pval8a = `counter8a' / `nb_iter'

local ri_pval1b = `counter1b' / `nb_iter'
local ri_pval2b = `counter2b' / `nb_iter'
local ri_pval3b = `counter3b' / `nb_iter'
local ri_pval4b = `counter4b' / `nb_iter'
local ri_pval5b = `counter5b' / `nb_iter'
local ri_pval6b = `counter6b' / `nb_iter'
local ri_pval7b = `counter7b' / `nb_iter'
local ri_pval8b = `counter8b' / `nb_iter'

*************************************************************
** 4. export results **
*************************************************************

*** export results!!!
matrix pval_table1_RI_nocontrols = (`ri_pval1a',`ri_pval2a',`ri_pval3a',`ri_pval4a' \ `ri_pval1b',`ri_pval2b',`ri_pval3b',`ri_pval4b')
matrix list pval_table1_RI_nocontrols
matrix pval_table1_RI_lasso = (`ri_pval5a',`ri_pval6a',`ri_pval7a',`ri_pval8a' \ `ri_pval5b',`ri_pval6b',`ri_pval7b',`ri_pval8b')
matrix list pval_table1_RI_lasso
clear
svmat pval_table1_RI_lasso
export delimited using "$outpath/table1_ri_pval_2016_lasso.csv", replace
clear
svmat pval_table1_RI_nocontrols
export delimited using "$outpath/table1_ri_pval_2016_nocontrols.csv", replace

*DONE!!!



