*************************************************************
* OLS
*************************************************************

*************************************************************
** 1. preliminary **
*************************************************************

set more off
clear

* Load data (using imputed data, even though no controls for this first set so does not matter)
use "$codeddata/180529_final_database_imputem_2016susenas.dta", clear

*merge with random treatments // these are the same random treatments as is used for the FWER
rename province province_string
rename code province
merge m:1 province using "$fake_tx/fake_tx.dta", force nogen assert(match)

** lasso controls ** note: these are taken from matlabregressions.do, case r = 3 in the matlab script
local n_cell_controls jul10_computer jul10_laptop jul10_lease pool11_soilfloor pool11_bottledwashwater pool12_computer pool12_concreteroof pool12_watt2200higher pool13_hhhouse4 pool14_bottledcookwater mar15_cleandrinkwater mar15_schoolinternet mar15_publicinternet mar15_int_financial mar15_personaltoilet mar15_protspringdrinkwate feb07_publicwater jul07_officeforinternet mar08_publicwater jul08_landlineforinternet jul08_lease jul08_watt2200higher mar09_rent jul09_energysource7 urban

local nb_iter = 1000

*************************************************************
** 2. lasso controls **
*************************************************************

* Lasso controls:
areg n_ppl_phones tr_tv tr_cell `n_cell_controls', absorb(strata_orig) cluster(province)
local lasso_2a = _b[tr_tv]
local lasso_2b = _b[tr_cell]

*************************************************************
** 3. start RI **
*************************************************************

local counter6a = 0
local counter6b = 0

** loop over fake randomizations
forv i = 1/`nb_iter' {

    gen tr_cell_`i' = 1 - tr_wc_`i'
    gen tr_room_`i' = 1 - tr_tv_`i'

    *** lasso controls ***
	areg n_ppl_phones tr_tv_`i' tr_cell_`i' `n_cell_controls', absorb(strata_orig) cluster(province)
	if abs(_b[tr_tv_`i']) > abs(`lasso_2a') local counter6a = `counter6a' + 1
	if abs(_b[tr_cell_`i']) > abs(`lasso_2b') local counter6b = `counter6b' + 1

    drop *_`i'

}

local ri_pval6a = `counter6a' / `nb_iter'
local ri_pval6b = `counter6b' / `nb_iter'

*************************************************************
** 4. export results **
*************************************************************

*** export results!!!
matrix pval_table1_RI_alt = (`ri_pval6a',`ri_pval6b')
matrix list pval_table1_RI_alt
clear
svmat pval_table1_RI_alt
export delimited using "$outpath/table1_alt_ri_pval_2016.csv", replace

*DONE!!!



