*************************************************************
* OLS
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off
clear

* Load data (using imputed data, even though no controls for this first set so does not matter)
use "$codeddata/180529_final_database_imputem_2016susenas.dta", clear

*************************************************************
** Organizing variables and collapsing data **
*************************************************************

*************************************************************
** Label variables **
*************************************************************

label var own_flattv "Own TV"
label var own_wcgoose "Own WC"
label var total_room "Nb. Rooms"
label var n_cell_hh "Nb. SIM Cards"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

*************************************************************
** OLS regressions w/ new data file **
*************************************************************

* No controls:
areg own_flattv tr_tv tr_cell , absorb(strata_orig) cluster(province)
sum own_flattv if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4.doc", replace se word label title("Appendix Table 4: Effect of Treatments on 2016 Self-Reported Asset Acquisition (Individual)") keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, None, Strata FE, YES) ///
addnote("Standard errors clustered at province level. Outcome variable is taken from SUSENAS March 2016 and treatment is from 2015 PBDT targeting questionnaire. Regression is at individual level. Controls are selected using Double Lasso. Dependent variable mean represents mean of dependent variable in entire sample. FWER test result is 1 if we can reject the null hypothesis at the 10% level.")

areg n_cell_hh tr_tv tr_cell , absorb(strata_orig) cluster(province)
sum n_cell_hh if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, None, Strata FE, YES)

areg total_room tr_room tr_wc , absorb(strata_orig) cluster(province)
sum total_room if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, None, Strata FE, YES)

areg own_wcgoose tr_room tr_wc , absorb(strata_orig) cluster(province)
sum own_wcgoose if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, None, Strata FE, YES)

*************************************************************
** Lasso **
*************************************************************

di "Doing individual level OLS regression using LASSO controls"

// load in data
use "$codeddata/180529_final_database_imputem_2016susenas.dta", clear

*************************************************************
** Label variables **
*************************************************************

label var own_flattv "Own TV"
label var own_wcgoose "Own WC"
label var total_room "Nb. Rooms"
label var n_cell_hh "Nb. SIM Cards"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

***********************
** locals ** note: these are taken from matlabregressions.do, case r = 3 in the matlab script
***********************

local flattv_controls mar10_personalsquattoilet jul10_computer jul10_lease jul10_personaltoilet jul10_watt2200 pool11_concreteroof pool11_soilfloor pool11_wattnometer pool11_electricity pool12_computer pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool12_electricity pool12_personalsquattoile pool12_mutualsquattoilet pool13_ownhouse pool13_watt2200 pool13_kerosene pool13_personalgoosetoile pool14_computer pool14_concreteroof pool14_bottledcookwater pool14_electricity mar15_cleandrinkwater mar15_publicinternet mar15_int_financial mar15_marblegranitefloor mar15_soilfloor mar15_personaltoilet mar15_notbuyingdrinkwater mar15_mutualsquattoilet feb07_concreteroof jul07_concreteroof jul08_landlineforinternet jul08_concreteroof jul09_homeforinternet jul09_n_hhotherinternet jul09_concreteroof jul09_personaltoilet jul09_watt2200higher jul09_personalsquattoilet urban

local wcgoose_controls jul10_bamboofloor jul10_squattoilet pool12_riverdrinkwater pool12_goosetoilet pool13_riverdrinkwater pool13_personalgoosetoile pool14_unprotspringdrinkw pool14_personalgoosetoile mar15_personaltoilet mar15_notbuyingdrinkwater mar15_nonelectricity mar15_personalsquattoilet mar15_publicsquattoilet feb07_otherelectricity mar08_otherroof mar08_personaltoilet mar09_riverdrinkwater mar09_otherelectricity
 
local n_cell_controls jul10_computer jul10_bamboofloor pool11_concreteroof pool11_soilfloor pool12_computer pool12_concreteroof pool13_hhhouse4 pool14_computer pool14_bottledcookwater pool14_refillcookwater mar15_cleandrinkwater mar15_schoolinternet mar15_publicinternet mar15_personaltoilet feb07_publicwater jul07_officeforinternet mar08_publicwater jul08_landlineforinternet mar09_rent jul09_watt2200higher urban
 
local total_room_controls pool11_shingleroof pool12_residential pool13_woodfloor pool13_publicsquattoilet mar15_personaltoilet mar15_riverdrinkwater mar15_publicnotoilet

areg own_flattv tr_tv tr_cell `flattv_controls', absorb(strata_orig) cluster(province)
sum own_flattv if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/table1.doc", replace se word label title("Table 1: Effect of Treatments on 2016 Self-Reported Asset Acquisition (Individual)") keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, Lasso, Strata FE, YES) ///
addnote("Standard errors clustered at province level. Outcome variable is taken from SUSENAS March 2016 and treatment is from 2015 PBDT targeting questionnaire. Regression is at individual level. Controls are selected using Double Lasso. Dependent variable mean represents mean of dependent variable in entire sample. FWER test result is 1 if we can reject the null hypothesis at the 10% level.")

areg n_cell_hh tr_tv tr_cell `n_cell_controls', absorb(strata_orig) cluster(province)
sum n_cell_hh if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/table1.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, Lasso, Strata FE, YES)

areg total_room tr_room tr_wc `total_room_controls', absorb(strata_orig) cluster(province)
sum total_room if e(sample) == 1 
local control_mean `r(mean)'
outreg2 using "$outpath/table1.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, Lasso, Strata FE, YES)

areg own_wcgoose tr_room tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
sum own_wcgoose if e(sample) == 1 
local control_mean `r(mean)'
outreg2 using "$outpath/table1.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean, `control_mean', FWER test at 10%, 1) addtext(Controls, Lasso, Strata FE, YES)


*DONE!!!



