*************************************************************
* OLS
*************************************************************

*************************************************************
** preliminary **
*************************************************************

set more off
clear

* Load data (using imputed data, even though no controls for this first set so does not matter)
use "$codeddata/180529_final_database_imputem_2017susenas.dta", clear

*************************************************************
** Organizing variables and collapsing data **
*************************************************************

*************************************************************
** Label variables **
*************************************************************

label var own_flattv "Own TV"
label var own_wcgoose "Own WC"
label var total_room "Nb. Rooms"
label var n_cell_hh "Nb. People with Phones"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

*************************************************************
** OLS regressions w/ new data file **
*************************************************************

* No controls:
areg own_flattv tr_tv tr_cell , absorb(strata_orig) cluster(province)
sum own_flattv if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4_2017.doc", replace se word label title("Appendix Table 4: Effect of Treatments on 2017 Self-Reported Asset Acquisition (Individual)") keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, None, Strata FE, YES) ///
addnote("Standard errors clustered at province level. Outcome variable is taken from SUSENAS 2017 and treatment is from 2015 PBDT targeting questionnaire. Regression is at individual level. Controls are selected using Double Lasso. Dependent variable mean represents mean of dependent variable in entire sample. FWER test result is 1 if we can reject the null hypothesis at the 10% level.")

areg n_cell_hh tr_tv tr_cell , absorb(strata_orig) cluster(province)
sum n_cell_hh if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4_2017.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, None, Strata FE, YES)

areg total_room tr_room tr_wc , absorb(strata_orig) cluster(province)
sum total_room if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4_2017.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, None, Strata FE, YES)

areg own_wcgoose tr_room tr_wc , absorb(strata_orig) cluster(province)
sum own_wcgoose if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/appendix_table4_2017.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, None, Strata FE, YES)

*************************************************************
** Lasso **
*************************************************************

di "Doing individual level OLS regression using LASSO controls"

// load in data
use "$codeddata/180529_final_database_imputem_2017susenas.dta", clear

*************************************************************
** Label variables **
*************************************************************

label var own_flattv "Own TV"
label var own_wcgoose "Own WC"
label var total_room "Nb. Rooms"
label var n_cell_hh "Nb. People with Phones"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

***********************
** locals ** note: these are taken from matlabregressions.do, case r = 3 in the matlab script
***********************

local flattv_controls mar10_concreteroof jul10_laptop jul10_lease jul10_watt2200 jul10_mutualsquattoilet pool11_lease pool11_personalgoosetoile pool12_concreteroof pool12_mutualwater pool12_watt2200higher pool13_rent pool14_computer pool14_bottledcookwater pool14_refillcookwater mar15_cleandrinkwater mar15_officeinternet mar15_int_financial mar15_lease mar15_concreteroof mar15_marblegranitefloor mar15_refillwashwater jul07_lease jul07_concreteroof mar08_lease jul08_landlineforinternet jul08_asbestosroof jul09_homeforinternet jul09_personaltoilet jul09_watt2200 jul09_watt2200higher urban

local wcgoose_controls pool11_personalgoosetoile pool11_personalsquattoile pool12_personalsquattoile pool13_oillamp pool14_mutualsquattoilet mar15_personaltoilet mar15_noaccesswater mar15_personalunclosedpit feb07_notoilet jul07_publicnotoilet mar08_goosetoilet
 
local n_cell_controls jul10_lease pool11_soilfloor pool11_publicwater pool12_computer pool12_concreteroof pool14_computer pool14_bottledcookwater mar15_cleandrinkwater mar15_officeinternet mar15_publicinternet mar15_int_financial mar15_personaltoilet jul07_officeforinternet jul07_lease jul08_landlineforinternet mar09_rent urban
 
local total_room_controls jul10_parrafinlamp pool12_residential pool13_residential pool13_woodfloor pool13_riverdrinkwater mar15_personaltoilet mar15_riverdrinkwater jul07_publicnotoilet


areg own_flattv tr_tv tr_cell `flattv_controls', absorb(strata_orig) cluster(province)
sum own_flattv if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/table1_2017.doc", replace se word label title("Table 1: Effect of Treatments on 2017 Self-Reported Asset Acquisition (Individual)") keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, Lasso, Strata FE, YES) ///
addnote("Standard errors clustered at province level. Outcome variable is taken from SUSENAS 2017 and treatment is from 2015 PBDT targeting questionnaire. Regression is at individual level. Controls are selected using Double Lasso. Dependent variable mean represents mean of dependent variable in entire sample. FWER test result is 1 if we can reject the null hypothesis at the 10% level.")

areg n_cell_hh tr_tv tr_cell `n_cell_controls', absorb(strata_orig) cluster(province)
sum n_cell_hh if e(sample) == 1
local control_mean `r(mean)'
outreg2 using "$outpath/table1_2017.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, Lasso, Strata FE, YES)

areg total_room tr_room tr_wc `total_room_controls', absorb(strata_orig) cluster(province)
sum total_room if e(sample) == 1 
local control_mean `r(mean)'
outreg2 using "$outpath/table1_2017.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, Lasso, Strata FE, YES)

areg own_wcgoose tr_room tr_wc `wcgoose_controls', absorb(strata_orig) cluster(province)
sum own_wcgoose if e(sample) == 1 
local control_mean `r(mean)'
outreg2 using "$outpath/table1_2017.doc", append se word label keep(tr_tv tr_wc tr_room tr_cell) nocons nor2 addstat(Dep. Variable Mean,`control_mean') addtext(Controls, Lasso, Strata FE, YES)


*DONE!!!



