*****************
** Table 3 Regressions
*****************

clear
set more off

use "$codeddata/telephone_sales/coded_all.dta", clear

*************************************
* Running basic regression
*************************************

** label variables
label var ln_subscribers "Log Subscribers"
label var tr_wc "WC Treatment"
label var tr_tv "TV Treatment"
label var tr_cell "Cell Treatment"
label var tr_room "Room Treatment"

local exp_vars_cell_room tr_cell tr_tv

forvalues year = 2015/2017 {

reg ln_subscribers `exp_vars_cell_room' if year==`year', robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/table3_`year'.doc", replace se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, N, Strata FE, N) title("Table 3: Effect of Treatments on SIM Card Ownership, `year'") ///
addnote("Dependent variable mean represents mean of dependent variable in entire sample. SIM Card data contains data on number of prepaid and postpaid active subscribers by province (kabupaten is only partially provided) and provider.")

reg ln_subscribers `exp_vars_cell_room' ln_pop if year==`year', robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/table3_`year'.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, N)

areg ln_subscribers `exp_vars_cell_room' ln_pop if year==`year', absorb(strata_orig) robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/table3_`year'.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, Y)

}

tempfile data
save "`data'"

*** ROBUSTNESS CHECK FOR BEN/REMA: drop Jakarta

drop if provice_str == "DKI JAKARTA"

forvalues year = 2015/2017 {

reg ln_subscribers `exp_vars_cell_room' if year==`year', robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table8_`year'_noJakarta.doc", replace se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, N, Strata FE, N) title("Appendix Table 6: Effect of Treatments on SIM Card Ownership, `year' -- Robustness Check: Dropped Jakarta") ///
addnote("Dependent variable mean represents mean of dependent variable in entire sample. SIM Card data contains data on number of prepaid and postpaid active subscribers by province (kabupaten is only partially provided) and provider.")

reg ln_subscribers `exp_vars_cell_room' ln_pop if year==`year', robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table8_`year'_noJakarta.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, N)

areg ln_subscribers `exp_vars_cell_room' ln_pop if year==`year', absorb(strata_orig) robust
sum ln_subscribers if e(sample) == 1
local control_mean_all `r(mean)'
outreg2 using "$outpath/appendix_table8_`year'_noJakarta.doc", append se word label keep(tr_cell tr_tv) nocons nor2 addstat(Dep. Variable Mean, `control_mean_all') addtext(Log population control, Y, Strata FE, Y)

}

*DONE!


