/***********************Susenas March 2016 Analysis with no baseline*************
Last modified: 170628
*************************/

clear
capture log close
set more off



**Opening March 2016 Susenas and keeping/recoding relevant files**
use "$rawdata/KOR/susenas17mar_kor17ind_a_diseminasi.dta", clear
rename fwt fwt_a
isid urut r401
merge 1:1 urut r401 using "$rawdata/KOR/susenas17mar_kor17ind_b_diseminasi.dta"
rename fwt fwt_b
assert _merge == 3
drop _merge
merge m:1 renum r101 r102 r105 using "$rawdata/KOR/susenas17mar_kor17rt_diseminasi.dta"
assert _merge == 3
drop _merge

assert fwt == fwt_a 
assert fwt == fwt_b
drop fwt_a fwt_b

**control: hh member**
rename r301 hhsize
tab hhsize, m
preserve
	gen ones = 1
	bysort urut: egen check = total(ones)
	assert check == hhsize
restore

**control: urban**
rename r105 urban
replace urban = 0 if urban == 2
tab urban, m

**cellphone**
rename r702 own_cell
replace own_cell= 0 if own_cell==5
bysort urut: egen n_cell_hh = total(own_cell)
tab own_cell, m
tab n_cell_hh, m

**renaming codes**
rename urut hhid
rename r101 code

**making district code
rename r102 district
tostring code district, replace
replace  district = "0" +  district if length(district)==1
gen districtcode = code+district 
destring code district districtcode, replace

**goose neck closet**
gen own_wcgoose = 1 if r1610a==1 & r1610b==1
replace own_wcgoose = 0 if own_wcgoose == .
tab own_wcgoose, m

**n room**
generate total_room = r1606a+r1606b+r1606c+r1606d+r1606e+r1606f+r1606g+r1606h
tab total_room, m

**flattv**
rename r2201l own_flattv
replace own_flattv = 0 if own_flattv==5
tab own_flattv, m

**social protection programs**
rename r2001 hh_raskin // last 4 months here, opposed to last 3 months in 2016 SUSENAS
replace hh_raskin=0 if hh_raskin==5
tab hh_raskin, m

rename r2005 hh_kps
replace hh_kps=1 if hh_kps==1 | hh_kps==2
replace hh_kps=0 if hh_kps==5
tab hh_kps, m

/*
*rename r1601 hh_blt
*replace hh_blt=0 if hh_blt==5
replace r1605a=0 if r1605a==5
*bysort hhid-r108: egen hh_pnpm = total(r1605a)
*replace hh_pnpm=1 if hh_pnpm!=0
*replace r1605b=0 if r1605b==5
bysort hhid-r108: egen hh_kur = total(r1605b)
replace hh_kur=1 if hh_kur!=0
replace r1605d=0 if r1605d==5
bysort hhid-r108: egen hh_kube = total(r1605d)
replace hh_kube=1 if hh_kube!=0
rename r1606 hh_bsm
replace hh_bsm=0 if hh_bsm==5
*/

**collapsing to HH level**
//bysort hhid-r108: gen n=_n
bysort hhid: gen n=_n
keep if n==1
drop n 

**merging database with randomization**
sort hhid
//drop r107 r108 r160* r1507a r1507b r1801a-r1801h
merge m:1 code using "$rawdata/randomization/randomization.dta"
assert _merge == 3
drop _merge

order code district province hhid
//drop own_cell n_cell_indiv strata_intermed strata_final 
saveold "$codeddata/Sus2017_merged_randomization.dta", replace

