********************************************
********************************************
** impute data for SUSENAS missing values
** take first non-missing subsequent survey value
********************************************
********************************************

set more off
clear

**************************
** impute missing values
**************************

forval yr = 2016/2017 {

** load in final data base
use "$codeddata/180529_final_database_`yr'SUSENAS.dta", clear

* drop 2005/2006 -- many missing kabupatens here and starting in 2007 will provide enough data for Lasso
drop *05_* *06_*

* reformat variables
ds *0?_* *1?_* urban
format `r(varlist)' %9.0g 

** these variables only happen in 1 or 2 surveys
rename jul07_pipeddrinkwater jul07_pipedrinkwater
drop feb07_pipedrinkwater 
drop jul07_pipedrinkwater jul07_unitarea jul07_computerforinternet jul07_n_hhmusecompint jul07_n_hhwarnetinternet jul07_n_hhofficeinternet jul07_watersource11 jul07_noaccesswater jul07_electricity 
drop jul08_n_hhwarnetforinternet jul08_n_hhofficeforinternet
drop jul09_n_hhwarnetforinternet jul09_n_hhofficeforinternet
drop mar09_noaccesswater 
drop mar10_lpgmore3kg mar10_carmotorboat mar10_unmeteredPLNelectricity

local all_vars "refrigerator motorcycle bicycle kerosene charcoal firewood otherenergy lpgas n_hhotherinternet n_hhschoolinternet officeforinternet schoolforinternet otherforinternet warnetforinternet cellphone n_hhcellphone cellphoneforinternet computer telephone area	buyingdrinkwater	totalfemale	totalmale	totalchild	month_pcexp	ownhouse	lease	rent	freelease	companyhouse	familyhouse	otherhouse	concreteroof	tileroof	shingleroof	ironsheetroof	asbestosroof	fiberpalmroof	otherroof	concretewall	woodwall	bamboowall	otherwall	soilfloor	bottleddrinkwater	refilldrinkwater	retailpipedrinkwater	meteredpipedrinkwater	pumpdrinkwater	protwelldrinkwater	unprotwelldrinkwater	protspringdrinkwater	unprotspringdrinkwater	riverdrinkwater	raindrinkwater	otherdrinkwater	cleanwatersanitation	personalwater	mutualwater	publicwater	noaccessdrinkwater	personaltoilet	mutualtoilet	publictoilet	noaccesstotoilet	goosetoilet	pitttoilet	squattoilet	notoilet	septicdisposal	pooldisposal	riverdisposal	pitholedisposal	opendisposal	otherdisposal	PLNelectricity	nonPLNelectricity	parrafinlamp	oillamp	otherelectricity	personalgoosetoilet	personalpitttoilet	personalsquattoilet	personalnotoilet	mutualgoosetoilet	mutualpitttoilet	mutualsquattoilet	mutualnotoilet	publicgoosetoilet	publicpitttoilet	publicsquattoilet	publicnotoilet"

foreach var in `all_vars' {
	display "`var'"

	display "feb07"
	cap noisily replace feb07_`var' = jul07_`var' 			if feb07_`var'==. & jul07_`var'!=. // not all variables have this survey round, so add "capture" to command
	cap noisily replace feb07_`var' = mar08_`var' 			if feb07_`var'==. & mar08_`var'!=. // not all variables have this survey round, so add "capture" to command
	cap noisily replace feb07_`var' = jul08_`var' 			if feb07_`var'==. & jul08_`var'!=. // not all variables have this survey round, so add "capture" to command
	capture confirm variable feb07_`var'
	if !_rc assert !missing(feb07_`var')

	display "jul07"
	cap noisily replace jul07_`var'= mar08_`var' 			if jul07_`var'==. & mar08_`var'!=.
	cap noisily replace jul07_`var'= jul08_`var' 			if jul07_`var'==. & jul08_`var'!=.
	cap noisily replace jul07_`var'= mar09_`var' 			if jul07_`var'==. & mar09_`var'!=.
	capture confirm variable jul07_`var'
	if !_rc assert !missing(jul07_`var')

	display "mar08"
	cap noisily replace mar08_`var' = jul08_`var'			if mar08_`var'==. & jul08_`var'!=.
	capture confirm variable mar08_`var'
	if !_rc assert !missing(mar08_`var')

	display "mar09"
	cap noisily replace mar09_`var' = jul09_`var' 			if mar09_`var'==. & jul09_`var'!=.
	capture confirm variable mar09_`var'
	if !_rc assert !missing(mar09_`var')

	display "mar10"
	cap noisily replace mar10_`var' = jul10_`var' 			if mar10_`var'==. & jul10_`var'!=.
	cap noisily replace mar10_`var' = pool11_`var' 			if mar10_`var'==. & pool11_`var'!=.
	capture confirm variable mar10_`var'
	if !_rc assert !missing(mar10_`var')

}

** make sure all covariates are non-missing
ds *07_* *08_* *09_* *10_* *11_* *12_* *13_* *14_* *15_* urban
foreach covariate in `r(varlist)' {
	assert !missing(`covariate')
}

** fix strata variable -- randomization used strata with 5 groups, not 7
gen strata = strata_orig
replace strata = "Nusa Tenggara, Maluku, Papua" if strata_orig == "Nusa Tenggara"
replace strata = "Nusa Tenggara, Maluku, Papua" if strata_orig == "Maluku"
replace strata = "Nusa Tenggara, Maluku, Papua" if strata_orig == "Papua"
drop strata_orig
rename strata strata_orig

** save final imputed data base
save "$codeddata/180529_final_database_imputem_`yr'susenas.dta", replace

} // close loop


*DONE!
