*****************
** Code telephone sales data
*****************

*****************
** preliminaries
*****************

clear all
set more off

** set locals for location of raw cell phone data, randomization assignment, and population data
local infile "$rawdata/telephone/20171128 Active Cellphone Subscribers Compiled.xlsx"
local tr_status "$rawdata/randomization/randomization.dta"
local pop "$rawdata/province_pop_2015.dta" // 2015 population data

*************************************
* Import raw file
*************************************

** import raw file
import excel "`infile'", sheet("Data Compiled") firstrow clear

** rename variables
ren *, lower
ren asofmonth month

* according to Poppy all missing provider-province combinations to be treated as missing. 
* However, if all providers are missing for a given year then that shouldn't be 0.
drop if noofactivesubscribers=="" | noofactivesubscribers=="-"

*************************************
* Number of subscribers per province in 2015/2016/2017
*************************************

destring noofactivesubscribers, gen(subscribers)

collapse (sum) subscribers, by(province year)

keep if year == 2016 | year==2017 | year==2015

*************************************
* Merging with treatment status
*************************************

* Aceh old name
replace province="Nanggroe Aceh Darussalam" if province=="ACEH"

replace province=upper(province)

gen province_code=.
replace province_code=51 if province=="BALI"
replace province_code=19 if province=="BANGKA BELITUNG"
replace province_code=36 if province=="BANTEN"
replace province_code=17 if province=="BENGKULU"
replace province_code=34 if province=="DI YOGYAKARTA"
replace province_code=31 if province=="DKI JAKARTA"
replace province_code=75 if province=="GORONTALO"
replace province_code=15 if province=="JAMBI"
replace province_code=32 if province=="JAWA BARAT"
replace province_code=33 if province=="JAWA TENGAH"
replace province_code=35 if province=="JAWA TIMUR"
replace province_code=61 if province=="KALIMANTAN BARAT"
replace province_code=63 if province=="KALIMANTAN SELATAN"
replace province_code=62 if province=="KALIMANTAN TENGAH"
replace province_code=64 if province=="KALIMANTAN TIMUR"
replace province_code=65 if province=="KALIMANTAN UTARA"
replace province_code=21 if province=="KEPULAUAN RIAU"
replace province_code=18 if province=="LAMPUNG"
replace province_code=81 if province=="MALUKU"
replace province_code=82 if province=="MALUKU UTARA"
replace province_code=11 if province=="NANGGROE ACEH DARUSSALAM"
replace province_code=52 if province=="NUSA TENGGARA BARAT"
replace province_code=53 if province=="NUSA TENGGARA TIMUR"
replace province_code=94 if province=="PAPUA"
replace province_code=91 if province=="PAPUA BARAT"
replace province_code=14 if province=="RIAU"
replace province_code=76 if province=="SULAWESI BARAT"
replace province_code=73 if province=="SULAWESI SELATAN"
replace province_code=72 if province=="SULAWESI TENGAH"
replace province_code=74 if province=="SULAWESI TENGGARA"
replace province_code=71 if province=="SULAWESI UTARA"
replace province_code=13 if province=="SUMATERA BARAT"
replace province_code=16 if province=="SUMATERA SELATAN"
replace province_code=12 if province=="SUMATERA UTARA"

ren province provice_str
ren province_code code

** merge with treatment status
merge m:1 code using "`tr_status'"
assert missing(code) if _merge != 3
drop _merge

* Kalimantan utara was split from 64 and should have the same treatment status as 64 -- it does

drop if tr_cell==.

*************************************
* Merge with population data
*************************************

rename province province_orig
rename code province
merge m:1 province using "`pop'"
assert _merge == 3
drop _merge

*************************************
* Taking logs of number of subscribers and population size
*************************************

gen ln_subscribers=ln(subscribers)
gen ln_pop=ln(population_2015)

****** fix strata variable
gen strata = strata_orig
replace strata = "Nusa Tenggara, Maluku, Papua" if strata_orig == "Nusa Tenggara"
replace strata = "Nusa Tenggara, Maluku, Papua" if strata_orig == "Maluku"
replace strata = "Nusa Tenggara, Maluku, Papua" if strata_orig == "Papua"
drop strata_orig
rename strata strata_orig
drop strata_final strata_intermed

*************************************
* Save coded telephone data
*************************************

save "$codeddata/telephone_sales/coded_all.dta", replace




