**********************************
** Code raw TV sales data
**********************************

*****************
** Preliminaries
*****************

clear 
set more off

**** note (from raw excel file)
/* Region Grouping	
Group1 [CELL, TV]	Sulawesi Utara, Sulawesi Barat, Nanggroe Aceh Darussalam (NAD), Lampung, Kalimantan Selatan, Jawa Barat, Bangka Belitung, Aceh, 
Group2 [CELL, not tv]	Sumatera Barat, Sulawesi Tenggara, Kalimantan Timur, Jawa Tengah, DKI Jakarta, Bengkulu, Bali, 
Group3 [not cell, TV]	Sumatera Selatan, Sulawesi Tengah, Kalimantan Tengah, Jawa Timur, Jambi, DI Yogyakarta, 
Group4 [not cell, not tv]	Sumatera Utara, Sulawesi Selatan, Riau, Kepulauan Riau, Kalimantan Barat, Gorontalo, Banten, 
*/
****

*****************
** Overall dataset
*****************

use "$codeddata/television_sales/data_overall.dta", clear

for var ???13 ???14 ???15 ???16: ren X dataX

reshape long data, i(metrics region) j(rawmonth) string

reshape wide data, i(region rawmonth) j(metrics) string

g group = real(substr(region,6,1))
g treatgroup = 1 if group == 1 | group == 3
replace treatgroup = 0 if group == 2 | group == 4

g date = monthly(rawmonth,"M20Y")

format date %tm

g tr_wc = 1 if group == 3 | group == 4
replace tr_wc = 0 if group == 1 | group == 2
g tr_tv = 1 if group == 1 | group == 3
replace tr_tv = 0 if group == 2 | group == 4
g tr_cell = 1 - tr_wc

** save coded overall data
save "$codeddata/television_sales/coded_overall.dta", replace

*****************
** Dataset by priceband
*****************

use "$codeddata/television_sales/data_priceband.dta", clear

for var ???13 ???14 ???15 ???16: ren X dataX

reshape long data, i(metrics region priceband) j(rawmonth) string

reshape wide data, i(region rawmonth priceband) j(metrics) string

g group = real(substr(region,6,1))
g treatgroup = 1 if group == 1 | group == 3
replace treatgroup = 0 if group == 2 | group == 4

g date = monthly(rawmonth,"M20Y")

format date %tm

** save coded priceband data
save "$codeddata/television_sales/coded_priceband.dta", replace

*****************
** Dataset by resolution
*****************

use "$codeddata/television_sales/data_resolution.dta", clear

for var ???13 ???14 ???15 ???16: ren X dataX

reshape long data, i(metrics region resolution) j(rawmonth) string

reshape wide data, i(region rawmonth resolution) j(metrics) string

g group = real(substr(region,6,1))
g treatgroup = 1 if group == 1 | group == 3
replace treatgroup = 0 if group == 2 | group == 4

g date = monthly(rawmonth,"M20Y")

format date %tm

** save coded resolution data
save "$codeddata/television_sales/coded_resolution.dta", replace

*****************
** Dataset by size
*****************

use "$codeddata/television_sales/data_size.dta", clear

ren resolution size

for var ???13 ???14 ???15 ???16: ren X dataX

reshape long data, i(metrics region size) j(rawmonth) string

reshape wide data, i(region rawmonth size) j(metrics) string

g group = real(substr(region,6,1))
g treatgroup = 1 if group == 1 | group == 3
replace treatgroup = 0 if group == 2 | group == 4

g date = monthly(rawmonth,"M20Y")

format date %tm

** save coded size data
save "$codeddata/television_sales/coded_size.dta", replace

*** DONE!



