/*
Purpose: Prepare povmap variable from Susenas
Based off 121120 Clean 2011 version

*/
set trace off
clear all
set mem 650m
set more off

**********************************************************************************************************************
**********************************************************************************************************************
* HH dataset * HH dataset * HH dataset * HH dataset * HH dataset * HH dataset * HH dataset * HH dataset * HH dataset 
**********************************************************************************************************************
**********************************************************************************************************************

use "$rawdata/susenas16mar_kr.dta", clear

*****************************************************************
* 0. Identifiers
***************************************************************

rename urut hhid

***************************************************************
* 1. Urban
***************************************************************

	*1. Klasifikasi tempat tinggal: perkotaan/perdesaan
	gen h_urban=r105==1 if r105!=.
	lab var h_urban "Klasifikasi tempat tinggal: perkotaan/perdesaan"
	lab def h_urban 1"Perkotaan" 0"Perdesaan"
	lab val h_urban h_urban

***************************************************************
* 2. HH size
***************************************************************

	*2. HH size
	gen h_hhsize=r301
	lab var h_hhsize "Jumlah anggota rumah tangga"

***************************************************************
* 3. House status
***************************************************************
	
	*41. Status penguasaan bangunan tempat tinggal: Milik sendiri
	gen h_house1=r1502==1 if r1502!=.
	lab var h_house1 "Status penguasaan bangunan tempat tinggal: Milik sendiri"
	lab def h_house1 1"Milik sendiri" 0"Lainnya"
	lab val h_house1 h_house1

	*42. Status penguasaan bangunan tempat tinggal: Sewa/kontrak
	gen h_house2=r1502==2 if r1502!=.
	lab var h_house2 "Status penguasaan bangunan tempat tinggal: Sewa/kontrak"
	lab def h_house2 1"Sewa/kontrak" 0"Lainnya"
	lab val h_house2 h_house2

	*43. Status penguasaan bangunan tempat tinggal: Bebas sewa
	gen h_house3=r1502==3 if r1502!=.
	lab var h_house3 "Status penguasaan bangunan tempat tinggal: Bebas sewa"
	lab def h_house3 1"Bebas sewa" 0"Lainnya"
	lab val h_house3 h_house3

	*44. Status penguasaan bangunan tempat tinggal: Rumah dinas
	gen h_house4=r1502==4 if r1502!=.
	lab var h_house4 "Status penguasaan bangunan tempat tinggal: Rumah dinas"
	lab def h_house4 1"Rumah dinas" 0"Lainnya"
	lab val h_house4 h_house4

** omitted category -- category 5 (other house)

***************************************************************
* 4. Floor/Wall/Roof type
***************************************************************

	* floor:
	for num 1/9: gen h_tfloorX = r1506 == X if r1506!=.

** omitted category -- category 10 (other floor)

	* wall:
	for num 1/6: gen h_twallX = r1505 == X if r1505!=.

** omitted category -- category 7 (other wall)

	* roof:
	for num 1/9: gen h_troofX = r1504 == X if r1504!=.

** omitted category -- category 10 (other roof)

***************************************************************
* 5. Water characteristics
***************************************************************

	* drink water sources
	for num 1/11: gen h_dwaterX = r1508a == X if r1508a!=.

** omitted category -- category 12 (other drink water source)

	* how to get drinking water
	for num 1/2: gen h_pwaterX = r1510 == X if r1510!=.

** omitted category -- category 3 (not buying drinking water)

***************************************************************
* 6. Lighting
***************************************************************

	* electricity source
	for num 1/2: gen h_lightingX = r1514 == X if r1514!=.

** omitted category -- category 3 (no electricity)

***************************************************************
* 7. Toilet / Septic
***************************************************************

	* toilet ownership
	for num 1/4: gen h_toiletX = r1507a == X if r1507a!=.

** omitted category -- category 5 (no access to toilet)

	* toilet dispoal
	for num 1/6: gen h_septicX = r1507c == X if r1507c!=.

** omitted category -- category 7 (other disposal)

***************************************************************
* 8. Assets
***************************************************************

	rename r1701a h_asset_lpg5kgmore
	replace h_asset_lpg5kgmore = 0 if h_asset_lpg5kgmore == 5
	rename r1701b h_asset_refrigerator
	replace h_asset_refrigerator = 0 if h_asset_refrigerator == 5
	rename r1701c h_asset_airconditioner
	replace h_asset_airconditioner = 0 if h_asset_airconditioner == 5
	rename r1701d h_asset_waterheater
	replace h_asset_waterheater = 0 if h_asset_waterheater == 5
	rename r1701e h_asset_landline
	replace h_asset_landline = 0 if h_asset_landline == 5
	rename r1701f h_asset_computer
	replace h_asset_computer = 0 if h_asset_computer == 5
	rename r1701g h_asset_goldjewelerymin10gram
	replace h_asset_goldjewelerymin10gram = 0 if h_asset_goldjewelerymin10gram == 5
	rename r1701h h_asset_motorcycle
	replace h_asset_motorcycle = 0 if h_asset_motorcycle == 5
	rename r1701i h_asset_boat
	replace h_asset_boat = 0 if h_asset_boat == 5
	rename r1701j h_asset_motorboat
	replace h_asset_motorboat = 0 if h_asset_motorboat == 5
	rename r1701k h_asset_car
	replace h_asset_car = 0 if h_asset_car == 5

tempfile hhfile
sa `hhfile', replace

**********************************************************************************************************************
**********************************************************************************************************************
* Individual dataset * Individual dataset * Individual dataset * Individual dataset * Individual dataset *
**********************************************************************************************************************
**********************************************************************************************************************

****************************************************************/
* Indicator from Susenas Core Individu

use "$rawdata/susenas16mar_ki.dta",clear

*****************************************************************
* 0. Identifiers
***************************************************************

rename urut hhid
isid hhid r401

***************************************************************
* 1. Age
***************************************************************

	*4. Umur KRT
	gen h_hhage=r407
	lab var h_hhage "Umur KRT"


***************************************************************
* 2. Gender
***************************************************************

	*6. Kepala RT laki-laki
	gen h_hhmale=r405==1 if  r405!=.
	lab var h_hhmale "Kepala rumah tangga laki-laki"
	lab def h_hhmale 1"Laki-laki" 0"Perempuan"
	lab val h_hhmale h_hhmale

***************************************************************
* 3. Marital status
***************************************************************

	*7. Status perkawinan KRT
	gen h_hhmarried=r404==2 if r401==1
	lab var h_hhmarried "Status perkawinan KRT"
	lab def h_hhmarried 1"Kawin" 0"Lainnya"
	lab val h_hhmarried h_hhmarried

***************************************************************
* 4. Dependents
***************************************************************

	*8. Jumlah anggota rumah tangga <= 14 tahun
	bys hhid: egen h_nage14=sum(h_hhage<=14)
	lab var h_nage14 "Jumlah anggota rumah tangga berumur <= 14 tahun"

	*9. Jumlah anggota rumah tangga >= 65 tahun
	bys hhid: egen h_nage65p=sum(h_hhage>64 & h_hhage <.)
	lab var h_nage65p "Jumlah anggota rumah tangga berumur >= 65 tahun"


***************************************************************
* 5. Education
***************************************************************

g edlevel = 0 if r508==1 | r508==2
replace edlevel = 1 if inrange(r508,3,6)
replace edlevel = 2 if inrange(r508,7,10)
replace edlevel = 3 if inrange(r508,11,14)
replace edlevel = 4 if inrange(r508,15,20)

bys hhid: egen maxedu = max(edlevel)

forv x = 1/2 {
local a : word `x' of edlevel maxedu 
local b : word `x' of h_hh h_hhmaxed
g `b'none = (`a'==0)
g `b'sd = (`a'==1)
g `b'smp = (`a'==2)
g `b'sma = (`a'==3)
g `b'dip1_s3 = (`a'==4)
}
ren h_hhnon h_hhedu_none

	*21. Jumlah ART bersekolah di D1 - S3
	bys hhid: egen h_nchilddip1_s3=sum(h_nage14 == 1 & inrange(r508,15,20))
	lab var h_nchilddip1_s3 "Jumlah ART bersekolah di D1 - S3"

***************************************************************
* 6. Occupation
***************************************************************

	for num 0/9: gen h_hhworkX = r1103 == X if !missing(r1103)
	for num 1/6: gen h_hhstatusworkX = r1104 == X if !missing(r1103)

/*	*29. Status KRT bekerja/membantu bekerja
	gen h_hhwork=b5r30!=. if hb==1			
	lab var h_hhwork "Status KRT bekerja/membantu bekerja"
	lab def h_hhwork 1"Bekerja" 0"Lainnya"
	lab val h_hhwork h_hhwork

	*30. Lapangan pekerjaan KRT: Pertanian
	gen h_hhagr=inrange(b5r30,1,6) if hb==1 & b5r30!=. & b5r30!=19
	lab var h_hhagr "Lapangan pekerjaan KRT: Pertanian"
	lab def h_hhagr 1"Pertanian" 0"Lainnya"
	lab val h_hhagr h_hhagr

	*31. Lapangan pekerjaan KRT: Industri
	gen h_hhind=inrange(b5r30,7,10) if hb==1 & b5r30!=. & b5r30!=19
	lab var h_hhind "Lapangan pekerjaan KRT: Industri"
	lab def h_hhind 1"Industri" 0"Lainnya"
	lab val h_hhind h_hhind

	*32. Lapangan pekerjaan KRT: Jasa
	gen h_hhserv=inrange(b5r30,11,19) if hb==1 & b5r30!=. & b5r30!=19
	lab var h_hhserv "Lapangan pekerjaan KRT: Pertanian"
	lab def h_hhserv 1"Jasa" 0"Lainnya"
	lab val h_hhserv h_hhserv

	*36. Status/kedudukan KRT dalam pekerjaan utama: berusaha sendiri
	gen h_workstat1=b5r31==1 if hb==1 & h_hhwork==1
	lab var h_workstat1 "Status KRT dlm pekerjaan utama: berusaha sendiri"
	lab def h_workstat1 1"Berusaha sendiri" 0"Lainnya"
	lab val h_workstat1 h_workstat1

	*37. Status/kedudukan KRT dalam pekerjaan utama: berusaha sendiri dibantu pekerja sementara
	gen h_workstat2=b5r31==2 if hb==1 & h_hhwork==1
	lab var h_workstat2 "Status KRT dlm pekerjaan utama: berusaha sendiri dibantu pekerja tidak tetap"
	lab def h_workstat2 1"Berusaha sendiri dibantu pekerja tidak tetap" 0"Lainnya"
	lab val h_workstat2 h_workstat2

	*38. Status/kedudukan KRT dalam pekerjaan utama: berusaha sendiri dibantu pekerja tetap
	gen h_workstat3=b5r31==3 if hb==1 & h_hhwork==1
	lab var h_workstat3 "Status KRT dlm pekerjaan utama: berusaha sendiri dibantu pekerja tidak tetap"
	lab def h_workstat3 1"Berusaha sendiri dibantu pekerja tidak tetap" 0"Lainnya"
	lab val h_workstat3 h_workstat3

	*37. Status/kedudukan KRT dalam pekerjaan utama: buruh/karyawan/pegawai
	gen h_workstat4=b5r31==4 if hb==1 & h_hhwork==1
	lab var h_workstat4 "Status KRT dlm pekerjaan utama: buruh/karyawan/pegawai"
	lab def h_workstat4 1"Buruh/karyawan/pegawai" 0"Lainnya"
	lab val h_workstat4 h_workstat4

	gen h_workstat5=b5r31==6 if hb==1 & h_hhwork==1
	
	gen h_workstat6=b5r31==5 if hb==1 & h_hhwork==1	
*/


**********************************************************************************************************************
**********************************************************************************************************************
* Merging * Merging * Merging * Merging * Merging * Merging * Merging * Merging * Merging * Merging * Merging *
**********************************************************************************************************************
**********************************************************************************************************************

merge m:1 hhid using `hhfile', nogen assert(match)

cap rename fwt wert

**flattv**
rename r1701l h_own_flattv
replace h_own_flattv = 0 if h_own_flattv==5

**n room**
generate h_total_room = r1801a+r1801b+r1801c+r1801d+r1801e+r1801f+r1801g+r1801h

**goose neck closet**
gen h_own_wcgoose = 1 if r1507a==1 & r1507b==1
replace h_own_wcgoose = 0 if h_own_wcgoose == .

**cellphone**
bysort hhid-r108: egen h_n_cell_hh = total(r1004b)
rename r1004b h_n_cell_indiv
replace h_n_cell_indiv = 0 if h_n_cell_indiv == .
rename r1004a h_own_cell
replace h_own_cell= 0 if h_own_cell==5
bysort hhid-r108: egen h_n_ppl_phones = total(h_own_cell)

rename r101 provincecode
rename r102 districtcode

drop r1* r2* r3* r4* r5* r6* r7* r8* r9*

**merging database with randomization**
sort hhid
rename provincecode code
merge m:1 code using "$rawdata/randomization/randomization.dta", assert(match) nogen

bys hhid: gen n=_n
keep if n==1
drop n

ds h_*, not
ds h_*

order code district province hhid
saveold "$codeddata/SUSENAS2016_all_variables_JEP.dta", replace


