**Creating a dataset to look at consumption levels for households**
* Based on 160212 final codin
**Katherine Durlacher**
**May 10 2012**

clear all
pause on
set seed 5678429
set sortseed 248593
set mem 500m
set more off 

* 1. clean poverty line *************************************

import excel "$rawdata/poverty lines.xlsx", sheet("table") firstrow clear

rename Perkotaan a1
rename Perdesaan a2
destring a2, force replace

rename A province

reshape long a, i(province) j(urban)
replace urban = 0 if urban == 2
rename a poverty_line
gen ln_poverty_line = ln(poverty_line)

gen poverty_line_1_5 = poverty_line * 1.5
gen ln_poverty_line_1_5 = ln(poverty_line_1_5)

rename province province_caps

replace province_caps = "KEPULAUAN RIAU" if province_caps == "KEP. RIAU"

save "$codeddata/poverty_lines.dta", replace

* 2. DUMMY VARIABLES *************************************

use "$codeddata/SUSENAS2016_all_variables_JEP.dta", clear 

* A. HH HEAD AGE
**HH head age, h_hhage, h_hhage2-quadratic version **
gen d_h_hhage0_30 = .
replace d_h_hhage0_30 = 0 if h_hhage != .
replace d_h_hhage0_30 = 1 if h_hhage != . & h_hhage <=30
label var d_h_hhage0_30 "HH head age less than/equal to 30"

gen d_h_hhage30_50 = .
replace d_h_hhage30_50 = 0 if h_hhage != .
replace d_h_hhage30_50 = 1 if h_hhage != . & h_hhage >30 & h_hhage <=50
label var d_h_hhage30_50 "HH head age 31-50"

gen d_h_hhage50 = .
replace d_h_hhage50 = 0 if h_hhage != .
replace d_h_hhage50 = 1 if h_hhage != . & h_hhage >50
label var d_h_hhage50 "HH head age 51+"

assert d_h_hhage0_30+d_h_hhage30_50+d_h_hhage50 == 1 | (d_h_hhage0_30==. & d_h_hhage30_50==. & d_h_hhage50 == .)

drop d_h_hhage50 // omitted category

* B. HH SEX AND MARITAL STATUS
**HH head sex: male, h_hhmale**
gen d_h_hhmale = h_hhmale
label var d_h_hhmale "HH head is male"

**HH marital status:married, h_hhmarried**
gen d_h_hhmarried = h_hhmarried
label var d_h_hhmarried "HH head is married"

* C. HH SIZE
**Household size: h_hhsize* **
gen d_h_hhsize0_2 = .
replace d_h_hhsize0_2 = 0 if h_hhsize != .
replace d_h_hhsize0_2 = 1 if h_hhsize != . & h_hhsize <=2
label var d_h_hhsize0_2 "Household size 1-2"

gen d_h_hhsize2_4 = .
replace d_h_hhsize2_4 = 0 if h_hhsize != .
replace d_h_hhsize2_4 = 1 if h_hhsize != . & h_hhsize >=3 & h_hhsize < 5
label var d_h_hhsize2_4 "Household size 3-4"

gen d_h_hhsize4 = .
replace d_h_hhsize4 = 0 if h_hhsize != .
replace d_h_hhsize4 = 1 if h_hhsize != . & h_hhsize >4
label var d_h_hhsize4 "Household size more than 4"
assert d_h_hhsize0_2+d_h_hhsize2_4+d_h_hhsize4==1 | (d_h_hhsize0_2==. & d_h_hhsize2_4 == . & d_h_hhsize4==.)

drop d_h_hhsize4 // ommitted category

* D. DEPENDENTS
**Dependency Ratio, h_depratio, h_nage14, h_nage65p**
**1 child**
gen d_h_depend_c1 = .
replace d_h_depend_c1 = 0 if h_nage14 != .
replace d_h_depend_c1 = 1 if h_nage14 == 1

**2 children**
gen d_h_depend_c2 = .
replace d_h_depend_c2 = 0 if h_nage14 != .
replace d_h_depend_c2 = 1 if h_nage14 == 2

**>2 children**
gen d_h_depend_c3m = .
replace d_h_depend_c3m = 0 if h_nage14 != .
replace d_h_depend_c3m = 1 if h_nage14 > 2 & h_nage14 != .
assert d_h_depend_c1+d_h_depend_c2+d_h_depend_c3m==0 | d_h_depend_c1+d_h_depend_c2+d_h_depend_c3m==1 | h_nage14==.

**hh member >65, h_nage65p**
gen d_h_depend_p65 = .
replace d_h_depend_p65 = 0 if h_nage65p != .
replace d_h_depend_p65 = 1 if h_nage65p > 0 & h_nage65p != .

label var d_h_depend_c1 "1 dependent child"
label var d_h_depend_c2 "2 dependent children"
label var d_h_depend_c3m "3 or more dependent children"
label var d_h_depend_p65 "Dependent older than 65"


* E. EDUCATION 
**maxeduc in 2011**
**Education attainment**
foreach var of varlist h_hhsd h_hhsmp h_hhsma h_hhdip1_s3 h_hhmaxedsd h_hhmaxedsmp h_hhmaxedsma h_hhmaxeddip1_s3 {
	gen d_`var' = `var'
	}

label var d_h_hhsd "Highest ed. level of HH head: elementary"
label var d_h_hhsmp "Highest ed. level of HH head: junior high"
label var d_h_hhsma "Highest ed. level of HH head: high school"
label var d_h_hhdip1_s3 "Highest ed. level of HH head: tertiary"
label var d_h_hhmaxedsd "Highest ed. level of anyone in HH: elementary"
label var d_h_hhmaxedsmp "Highest ed. level of anyone in HH: junior high"
label var d_h_hhmaxedsma "Highest ed. level of anyone in HH: high school"
label var d_h_hhmaxeddip1_s3 "Highest ed. level of anyone in HH: tertiary"

* F. CHILDREN'S EDUCATION
**Children enrolled in tertiary ed"
gen d_h_childdip1_s3_1 = .
replace d_h_childdip1_s3_1 = 0 if h_nchilddip1_s3 != .
replace d_h_childdip1_s3_1 = 1 if h_nchilddip1_s3 == 1

gen d_h_childdip1_s3_2 = .
replace d_h_childdip1_s3_2 = 0 if h_nchilddip1_s3 != .
replace d_h_childdip1_s3_2 = 1 if h_nchilddip1_s3 == 2

gen d_h_childdip1_s3_3 = .
replace d_h_childdip1_s3_3 = 0 if h_nchilddip1_s3 != .
replace d_h_childdip1_s3_3 = 1 if h_nchilddip1_s3 >= 3 & h_nchilddip1_s3 != .

label var d_h_childdip1_s3_1 "1 child in tertiary ed"
label var d_h_childdip1_s3_2 "2 child in tertiary ed"
label var d_h_childdip1_s3_3 "3 or more children in tertiary ed"
assert d_h_childdip1_s3_1+d_h_childdip1_s3_2+d_h_childdip1_s3_3==1 | d_h_childdip1_s3_1+d_h_childdip1_s3_2+d_h_childdip1_s3_3==0 | h_nchilddip1_s3==.

* G. OCCUPATION OF HH HEAD
for num 0/9: gen d_h_hhworkX = h_hhworkX

label var d_h_hhwork0 "Occupation: Other"
label var d_h_hhwork1 "Occupation: Agriculture"
label var d_h_hhwork2 "Occupation: Mining"
label var d_h_hhwork3 "Occupation: Processing Industry"
label var d_h_hhwork4 "Occupation: Electricity and Gas"
label var d_h_hhwork5 "Occupation: Building and Construction"
label var d_h_hhwork6 "Occupation: Trade"
label var d_h_hhwork7 "Occupation: Information Transportation"
label var d_h_hhwork8 "Occupation: Finance and Insurance"
label var d_h_hhwork9 "Occupation: Services"

drop d_h_hhwork9 // omitted category

for num 1/6: gen d_h_hhstatusworkX = h_hhstatusworkX

label var d_h_hhstatuswork1 "Employment Status: Self"
label var d_h_hhstatuswork2 "Employment Status: Temporary"
label var d_h_hhstatuswork3 "Employment Status: Permanent"
label var d_h_hhstatuswork4 "Employment Status: Employee"
label var d_h_hhstatuswork5 "Employment Status: Workers are free"
label var d_h_hhstatuswork6 "Employment Status: Family workers"

drop d_h_hhstatuswork6 // omitted category

/*
***Occupation of HHH***
*hhh works*
gen d_h_hhwork = h_hhwork
gen d_h_hhagr = h_hhagr
gen d_h_hhind = h_hhind
gen d_h_hhserv = h_hhserv

label var d_h_hhwork "HHH works"
label var d_h_hhagr "HHH works in agriculture sector"
label var d_h_hhind "HHH works in industry sector"
label var d_h_hhserv "HHH works in service sector"

forv x = 1/6 {
gen d_h_workstat`x' = h_workstat`x'
}

label var d_h_workstat1 "HHH self employed"
label var d_h_workstat2 "HHH self employed w/ unpaid empl"
label var d_h_workstat3 "HHH self employed w/ paid empl"
label var d_h_workstat4 "HHH employee"
la var d_h_workstat5 "Unpaid family worker"
la var d_h_workstat6 "Freelance or casual laborer"

g temp = 0
forv x = 1/6 {
replace temp = temp+d_h_workstat`x'
}
assert temp==1 if d_h_hhwork==1
drop temp
*/


* H HOUSING ETC
***Housing and Facilities***
for num 1/9: gen d_h_troofX = h_troofX

label var d_h_troof1 "Roof: Concrete"
label var d_h_troof2 "Roof: Tile"
label var d_h_troof3 "Roof: Metal"
label var d_h_troof4 "Roof: Clay"
label var d_h_troof5 "Roof: Asbestos"
label var d_h_troof6 "Roof: Iron"
label var d_h_troof7 "Roof: Bamboo"
label var d_h_troof8 "Roof: Shingle wood"
label var d_h_troof9 "Roof: Fiber palm"

* Wall
for num 1/6: gen d_h_twallX = h_twallX

label var d_h_twall1 "Walls: Concrete"
label var d_h_twall2 "Walls: Woven bamboo"
label var d_h_twall3 "Walls: Wood"
label var d_h_twall4 "Walls: Woven wood"
label var d_h_twall5 "Walls: Log wood"
label var d_h_twall6 "Walls: Bamboo"

* Floor
for num 1/9: gen d_h_tfloorX = h_tfloorX

label var d_h_tfloor1 "Floor: Marble granite"
label var d_h_tfloor2 "Floor: Ceramic"
label var d_h_tfloor3 "Floor: Parquette vinyl"
label var d_h_tfloor4 "Floor: Tile"
label var d_h_tfloor5 "Floor: High quality wood"
label var d_h_tfloor6 "Floor: Cement brick"
label var d_h_tfloor7 "Floor: Bamboo"
label var d_h_tfloor8 "Floor: Low quality wood"
label var d_h_tfloor9 "Floor: Soil"

* Housing type
for num 1/4: gen d_h_houseX = h_houseX

label var d_h_house1 "House: Owned"
label var d_h_house2 "House: Rented"
label var d_h_house3 "House: Rented for free"
label var d_h_house4 "House: Company"

* Drinking water
for num 1/11: gen d_h_dwaterX = h_dwaterX

label var d_h_dwater1 "Drinking water: bottle"
label var d_h_dwater2 "Drinking water: refill"
label var d_h_dwater3 "Drinking water: retail tap"
label var d_h_dwater4 "Drinking water: metered tap"
label var d_h_dwater5 "Drinking water: pump"
label var d_h_dwater6 "Drinking water: protected well"
label var d_h_dwater7 "Drinking water: unprotected well"
label var d_h_dwater8 "Drinking water: protected spring"
label var d_h_dwater9 "Drinking water: unprotected spring"
label var d_h_dwater10 "Drinking water: river"
label var d_h_dwater11 "Drinking water: rain"

for num 1/2: gen d_h_pwaterX = h_pwaterX

label var d_h_pwater1 "HH pays for drinking water"
label var d_h_pwater2 "HH subscribes for drinking water"


* Toilet
for num 1/4: gen d_h_toiletX = h_toiletX

label var d_h_toilet1 "Toilet: personal"
label var d_h_toilet2 "Toilet: mutual"
label var d_h_toilet3 "Toilet: communal"
label var d_h_toilet4 "Toilet: public"

* Septic
for num 1/6: gen d_h_septicX = h_septicX

label var d_h_septic1 "Disposal: septic"
label var d_h_septic2 "Disposal: pool"
label var d_h_septic3 "Disposal: river"
label var d_h_septic4 "Disposal: pit hole"
label var d_h_septic5 "Disposal: open"
label var d_h_septic6 "Disposal: other"


* Lighting
g d_h_lighting1 = h_lighting1
g d_h_lighting2 = h_lighting2

la var d_h_lighting1 "PLN electricity"
la var d_h_lighting2 "Non-PLN electricity"

* I. ASSETS
***Asset Ownership***
gen d_h_asset_lpg5kgmore = h_asset_lpg5kgmore
gen d_h_asset_refrigerator = h_asset_refrigerator
gen d_h_asset_airconditioner = h_asset_airconditioner
gen d_h_asset_waterheater = h_asset_waterheater
gen d_h_asset_landline = h_asset_landline
gen d_h_asset_computer = h_asset_computer
gen d_h_asset_goldjewelerymin10gram = h_asset_goldjewelerymin10gram
gen d_h_asset_motorcycle = h_asset_motorcycle
gen d_h_asset_boat = h_asset_boat
gen d_h_asset_motorboat = h_asset_motorboat
gen d_h_asset_car = h_asset_car

label var d_h_asset_lpg5kgmore "HH has a lpg (5kg or more)"
label var d_h_asset_refrigerator "HH has a refrigerator"
label var d_h_asset_airconditioner "HH has a air conditioner"
label var d_h_asset_waterheater "HH has a waterheater"
label var d_h_asset_landline "HH has a landline"
label var d_h_asset_computer "HH has a computer"
label var d_h_asset_goldjewelerymin10gram "HH has a gold jewelry (10 gram)"
label var d_h_asset_motorcycle "HH has a motorcycle"
label var d_h_asset_boat "HH has a boat"
label var d_h_asset_motorboat "HH has a motorboat"
label var d_h_asset_car "HH has a car"

*poverty line variables
* J. URBAN

**dummy urban-rural var**
gen d_h_urban = h_urban
label define urban_lab 1 "urban" 0 "rural"
label val d_h_urban urban_lab
label var d_h_urban "Urban"

* 4. FOR PODES DATA ********************************************

/* 

*******for Podes data************
gen d_pds_road = pds_road
label var d_pds_road "Asphalt road"

gen d_pds_sma = pds_sma
label var d_pds_sma "SMA - senior high school"

gen d_pds_smp = pds_smp
label var d_pds_smp "SMP - junior high school"

gen d_pds_sd = pds_sd
label var d_pds_sd "SD - elementary school"


gen d_pds_puskesmas = pds_puskesmas
label var d_pds_puskesmas "Puskesmas - health facility"

gen d_pds_polindes = pds_polindes
label var d_pds_polindes "Polindes - health facility"

gen d_pds_doctor = pds_doctor
label var d_pds_doctor "Doctor"

gen d_pds_bidan = pds_bidan
label var d_pds_bidan "Midwife"

gen d_pds_office = pds_office
label var d_pds_office "Post office"

gen d_pds_credit = pds_credit
label var d_pds_credit "Credit facility"


****pds_distance create 4 dummies based on distance quartiles****
xtile pds_distance_quar = pds_distance, nq(4)

gen d_pds_dist1 = 0 if pds_distance_quar != .
replace d_pds_dist1 = 1 if pds_distance_quar == 1
gen d_pds_dist2 = 0 if pds_distance_quar != .
replace d_pds_dist2 = 1 if pds_distance_quar == 2
gen d_pds_dist3 = 0 if pds_distance_quar != .
replace d_pds_dist3 = 1 if pds_distance_quar == 3
gen d_pds_dist4 = 0 if pds_distance_quar != .
replace d_pds_dist4 = 1 if pds_distance_quar == 4

label var d_pds_dist1 "1st quartile: Dist. nearest city/district center"
label var d_pds_dist2 "2nd quartile: Dist. nearest city/district center"
label var d_pds_dist3 "3rd quartile: Dist. nearest city/district center"
label var d_pds_dist4 "4th quartile: Dist. nearest city/district center"

drop pds_distance_quar




cap g d_h_urban = h_urban

gen feb2010 = 0 if date != ""
replace feb2010 = 1 if date == "February 2010"
gen mar2011 = 0 if date != ""
replace mar2011 = 1 if date == "March 2011"
gen jun2011 = 0 if date != ""
replace jun2011 = 1 if date == "June 2011"
gen sep2011 = 0 if date != ""
replace sep2011 = 1 if date == "September 2011"

label define yesno 0 "No" 1 "Yes"

*/



* 5. MERGE WITH POVERTY LINE

** merge with poverty lines
gen urban = d_h_urban
gen province_caps = upper(province)
merge m:1 province_caps urban using "$codeddata/poverty_lines.dta", gen(poverty_merge)
assert poverty_merge != 1 if tr_tv == 0
keep if poverty_merge != 2
drop urban

/*
* omitting categories
drop d_h_hhage50
drop d_h_hhsize4
drop d_h_hhedu_none
drop d_h_hhserv
drop d_h_workstat6
drop d_h_house5
drop d_h_troof5
drop d_h_twall3
drop d_h_dwater6
drop d_h_lighting4
drop d_h_toilet3
*/

save "$codeddata/SUSENAS2016_all_variables_JEP_FINAL.dta", replace 


